/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 02884
 |        NATIONAL TREATMENT IMPROVEMENT EVALUATION STUDY (NTIES),
 |                               1992-1997
 |      (DATASET 0003: NTIES POSTDISCHARGE ASSESSMENT QUESTIONNAIRE
 |                                (NPAQ))
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\02884-0003-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE p4ffffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ADOLESCENT DETENTION' 2='(2) JAIL' 3='(3) PRISON'
                  4='(4) OTHER SITES' ;
  VALUE p5ffffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) MALE' 2='(2) FEMALE' ;
  VALUE p7ffffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ENGLISH' 2='(2) SPANISH' 3='(3) OTHER' 4='(4) DEPENDS' ;
  VALUE p11fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 0='(0) NO'
                  1='(1) YES' ;
  VALUE p13fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) STILL IN TX' 2='(2) NOT IN TX' ;
  VALUE p26fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  17='(17) 17 OR YOUNGER' 18='(18) 18' 19='(19) 19' 20='(20) 20' 21='(21) 21' 22='(22) 22'
                  23='(23) 23' 24='(24) 24' 25='(25) 25' 26='(26) 26' 27='(27) 27' 28='(28) 28' 29='(29) 29'
                  30='(30) 30' 31='(31) 31' 32='(32) 32' 33='(33) 33' 34='(34) 34' 35='(35) 35' 36='(36) 36'
                  37='(37) 37' 38='(38) 38' 39='(39) 39' 40='(40) 40' 41='(41) 41' 42='(42) 42' 43='(43) 43'
                  44='(44) 44' 45='(45) 45' 46='(46) 46' 47='(47) 47' 48='(48) 48' 49='(49) 40' 50='(50) 50'
                  51='(51) 51 OR OLDER' ;
  VALUE p87fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) DOB MATCHES INTAKE' 2='(2) DOB DOES NOT MATCH INTAKE' ;
  VALUE p88fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' ;
  VALUE p92fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p96fffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-12 MONTHS'
                  4='(4) MORE THAN 1 YEAR' 5='(5) INCARCERATED SINCE LAST INTERVIEW'
                  6='(6) NOT INCARCERATED' ;
  VALUE p102m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p102m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p102m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p102m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p114ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p121ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE p130ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) STILL IN TREATMENT' 2='(2) STOPPED TREATMENT' ;
  VALUE prgmtype  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CRITICAL POPULATIONS' 2='(2) CORRECTIONAL SETTINGS'
                  3='(3) NON-INCARCERATED OFFENDERS' 4='(4) TARGET CITIES'
                  5='(5) ADOLESCENT/JUVENILE JUSTICE' 6='(6) PUBLIC HOUSING' ;
  VALUE trt2ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) SHORT-TERM RESIDENTIAL/IN-PATIENT'
                  2='(2) LONG-TERM RESIDENTIAL/IN-PATIENT'
                  3='(3) OUT-PATIENT METHADONE' 4='(4) AMBULATORY OUT-PATIENT' ;
  VALUE prg2ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CRITICAL POPULATIONS/AJJ/PH' 2='(2) CRIMINAL JUSTICE'
                  3='(3) TARGET CITIES' ;
  VALUE cell      -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CP/SR' 2='(2) CP/LR' 3='(3) CP/OP' 4='(4) TC/SR' 5='(5) TC/LR' 6='(6) TC/OP'
                  7='(7) CJ/SR' 8='(8) CJ/LR' 9='(9) CJ/OP' 10='(10) METHADONE' ;
  VALUE cell2fff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) METHADONE' 2='(2) NON-METHADONE OUT-PATIENT'
                  3='(3) SHORT-TERM RESIDENTIAL' 4='(4) LONG-TERM RESIDENTIAL'
                  5='(5) CORRECTIONAL SETTINGS' ;
  VALUE p137ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  6='(6) 6TH GRADE OR LOWER' 7='(7) 7TH GRADE' 8='(8) 8TH GRADE'
                  9='(9) 9TH GRADE' 10='(10) 10TH GRADE' 11='(11) 11TH GRADE'
                  12='(12) 12TH GRADE' 13='(13) 1 YEAR COLLEGE/TECHNICAL SCHOOL'
                  14='(14) 2 YEARS COLLEGE/TECHNICAL SCHOOL'
                  15='(15) 3 YEARS COLLEGE/TECHNICAL SCHOOL'
                  16='(16) 4 YEARS COLLEGE/TECHNICAL SCHOOL OR MORE' ;
  VALUE p138ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p139m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p139m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p139m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p139m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p139m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p139m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p139m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p145ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p146ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) HIGH SCHOOL DIPLOMA' 2='(2) GED CERTIFICATE' ;
  VALUE p150ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VOCATIONAL/TECHNICAL/LICENSE' 2='(2) OTHER DEGREE' 3='(3) NONE' ;
  VALUE p155ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p159ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p160ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) EXCELLENT?' 2='(2) GOOD?' 3='(3) FAIR?' 4='(4) POOR?' ;
  VALUE p161ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) BETTER THAN AVERAGE' 2='(2) AVERAGE' 3='(3) NOT SO GOOD' ;
  VALUE p162ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p164ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p165ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p172a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p172a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES, DRUGS USED' 2='(2) NO, DRUGS NOT USED' ;
  VALUE p181a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p188a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE p181a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p188a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE p181a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p182a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p183a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p186a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p188a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE p181a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p182a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p183a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7 OR MORE MONTHS AGO' ;
  VALUE p186a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p188a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE p181a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p188a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 4='(4) 11-20 DAYS' 5='(5) 21 DAYS OR MORE' ;
  VALUE p181a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p188a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE p181a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7 OR MORE MONTHS AGO' ;
  VALUE p188a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE p181a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' ;
  VALUE p188a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS' ;
  VALUE p181a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' ;
  VALUE p188a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 5 OR LESS DAYS' 2='(2) MORE THAN 5 DAYS' ;
  VALUE p181a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p188a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 5 OR LESS DAYS' 2='(2) MORE THAN 5 DAYS' ;
  VALUE p181a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p187a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' ;
  VALUE p188a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS'
                  5='(5) 21 DAYS OR MORE' ;
  VALUE p181a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p186a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 5 OR LESS DAYS' 2='(2) MORE THAN 5 DAYS' ;
  VALUE p187a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 7 MONTHS AGO' 2='(2) 7 OR MORE MONTHS AGO' ;
  VALUE p188a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 5='(5) 21 DAYS OR MORE' ;
  VALUE p189ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH'
                  4='(4) R DID NOT USE DRUGS OTHER THAN ALCOHOL D' ;
  VALUE p190ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p191ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7 OR MORE MONTHS AGO' ;
  VALUE p192ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) 2 OR MORE TIMES' ;
  VALUE p193ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1-20' 2='(2) 21-100' 3='(3) 101-200' 4='(4) 201-300'
                  5='(5) 301-400' 6='(6) 401-500' 7='(7) 501-600' 8='(8) 601-700' 9='(9) 701-800'
                  10='(10) 801-900' 11='(11) 901-1000' 12='(12) 1001-2000' 13='(13) 2001-3000'
                  14='(14) MORE THAN 3000' ;
  VALUE p194ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p195ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) SKIPPED YES TO 194' ;
  VALUE p196ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7 OR MORE MONTHS AGO' 4='(4) NO IVDU SINCE NTEQ' ;
  VALUE p197ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE DAY' 2='(2) 2-5 DAYS' 3='(3) 6-10 DAYS' 4='(4) 11-20 DAYS OR'
                  5='(5) 21 DAYS OR MORE?' ;
  VALUE p198ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p199ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7 OR MORE MONTHS AGO' 5='(5) NO SHARING SINCE NTEQ' ;
  VALUE p201ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN HALF OF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF OF THE TIME'
                  5='(5) EVERY TIME' 7='(7) NO SHARING SINCE NTEQ' ;
  VALUE p202ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN HALF OF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF OF THE TIME'
                  5='(5) EVERY TIME' 6='(6) NO IVDU SINCE NTEQ'
                  7='(7) NO SHARING SINCE NTEQ' ;
  VALUE p203ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN HALF OF THE TIME'
                  3='(3) HALF OF THE TIME' 4='(4) MORE THAN HALF OF THE TIME'
                  5='(5) EVERY TIME' 7='(7) NO SHARING SINCE NTEQ' ;
  VALUE p204ffff  -2='(-2) DON''T KNOW' 1='(1) NONE' 2='(2) ONE OR MORE DAYS'
                  4='(4) NO SHARING SINCE NTEQ' 5='(5) NO SHARING PAST MONTH' ;
  VALUE p205ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p206ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE p208a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE p209a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6' 9='(9) 7-11' 12='(12) 12' 18='(18) 13-22'
                  24='(24) 24' 40='(40) 40 OR MORE' ;
  VALUE p210a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CANS' 2='(2) BOTTLES' 3='(3) GLASSES' 4='(4) QUARTS' 5='(5) PINTS'
                  10='(10) OTHER' ;
  VALUE p213a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  8='(8) 2-11' 12='(12) 12' 16='(16) 13-24' 40='(40) 25+' ;
  VALUE p208a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE p209a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE p210a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  2='(2) BOTTLES' 3='(3) GLASSES' 6='(6) FIFTHS' 10='(10) OTHER' ;
  VALUE p213a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  6='(6) 1-8' 12='(12) 9-15' 16='(16) 16' 32='(32) 17+' ;
  VALUE p208a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE p209a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4' 6='(6) 5-10' 20='(20) 11 OR MORE' ;
  VALUE p210a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  4='(4) QUARTS' 5='(5) PINTS' 6='(6) FIFTHS' 7='(7) 1/2 PINTS' 8='(8) SHOTS'
                  9='(9) DRINKS' 10='(10) OTHER' ;
  VALUE p221ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE DAY' 3='(3) 2-5 DAYS' 4='(4) 6-10 DAYS'
                  5='(5) 11-20 DAYS' 6='(6) 21 DAYS OR MORE' ;
  VALUE p223ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p225ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p227ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH' ;
  VALUE p229ffff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE p237ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p238ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p239ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p240ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p241ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p242ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p243ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p244ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p245ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p250a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p250a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p250a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p250a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) MORE THAN 3 MONTHS' ;
  VALUE p250a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1 OR MORE MONTHS' ;
  VALUE p250a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p250a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p250a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p249a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 3 MONTHS OR LESS' 2='(2) MORE THAN 3 MONTHS' ;
  VALUE p250a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p252ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) RS OWN APARTMENT/HOUSE'
                  2='(2) SOMEONE ELSES APARTMENT/HOUSE'
                  3='(3) HOTEL, MOTEL, ROOMING/BOARDING HOUSE/DOR'
                  4='(4) HOMELESS SHELTER/ON STREET' 5='(5) OTHER TYPE OF SHELTER'
                  6='(6) HOSPITAL' 7='(7) IN JAIL/PRISON/DETENTION/WORK RELEASE'
                  8='(8) OTHER TYPE OF GROUP HOME/TREATMENT CENTE'
                  9='(9) SOME OTHER PLACE' ;
  VALUE p254ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p255ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE p256ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' ;
  VALUE p257ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p258ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p259ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6 OR MORE' ;
  VALUE p262a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p262a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p262a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p262a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p262a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p264a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p266a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p264a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p266a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p264a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p266a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p264a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p266a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p264a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-3 MONTHS' 3='(3) 4-6 MONTHS'
                  4='(4) 7-9 MONTHS' 5='(5) 10-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p266a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p267ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p268m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p268m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p268m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p268m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p269ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p270m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p270m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p270m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p271ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p272m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p272m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p272m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p272m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p273ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p274ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p275ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p276ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p278ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 0='(0) 0'
                  1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5 OR MORE' ;
  VALUE p279ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) R DOESNT HAVE CUSTODY OF ANY CHILDREN'
                  4='(4) R DOESNT USE DRUGS/ALCOHOL ANY MORE' ;
  VALUE p280ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p281ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p283ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p284ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN ONE MONTH' 2='(2) 1-6 MONTHS' 3='(3) 7-12 MONTHS'
                  4='(4) MORE THAN 12 MONTHS' ;
  VALUE p285ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5 OR MORE' ;
  VALUE p286ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p287ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p289ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  41='(41) 41+' ;
  VALUE p290ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  41='(41) 41+' ;
  VALUE p291ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  41='(41) 41+' ;
  VALUE p292ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT ASKED OF ADULTS' ;
  VALUE p294ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT ASKED OF ADULTS' ;
  VALUE p295ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT ASKED OF ADULTS' ;
  VALUE p296ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p297ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p298ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) 2-5 TIMES' 3='(3) 6 OR MORE TIMES' ;
  VALUE p299ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO' ;
  VALUE p301ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p302ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p303ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE p304ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p305ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE p306ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p307ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE p308ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p309ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE p310ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p311ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE p312ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT ASKED OF ADULTS' ;
  VALUE p316ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p317ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p319ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3 OR MORE' ;
  VALUE p321ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 1 WEEK' 2='(2) 1-2 WEEKS' 3='(3) 3-4 WEEKS'
                  4='(4) 1-6 MONTHS' 5='(5) 7-12 MONTHS' 6='(6) MORE THAN 12 MONTHS' ;
  VALUE p323ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) INPATIENT' 2='(2) RESIDENTIAL' 3='(3) OUTPATIENT' 4='(4) METHADONE' ;
  VALUE p324ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE p326ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ENTER PROVIDER' 2='(2) NONE MENTIONED' ;
  VALUE p332m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE p333a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE p332m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE p333a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE p332m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE p333a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE p332m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  0='(0) NONE' 1='(1) 1' 2='(2) 2 OR MORE' ;
  VALUE p333a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE p334ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p335m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p335m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p335m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p336ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p337ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) VERY HELPFUL' 2='(2) SOMEWHAT HELPFUL'
                  3='(3) NOT AT ALL HELPFUL' ;
  VALUE p338ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p342ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) TOO HIGH' 2='(2) THE RIGHT AMOUNT' 3='(3) TOO LOW' ;
  VALUE p344ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p345ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' ;
  VALUE p346ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p347ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) 1-5 TIMES' 3='(3) 6-10 TIMES' 4='(4) 11-30 TIMES'
                  5='(5) 31 TIMES OR MORE' ;
  VALUE p348ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p350ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p351ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p352ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE p353ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p354ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p355ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p356ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p357ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p358ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p359ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE OF THE TIMES' 2='(2) SOME OF THE TIMES'
                  3='(3) ALL OF THE TIMES' ;
  VALUE p360ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p361ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p362ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p363ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE p364ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p365ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE p367ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p368ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) SOME' 3='(3) ALL' ;
  VALUE p369ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH' ;
  VALUE p378ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p379ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p380ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p381ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p382ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p383ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p384ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p385ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p386ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p387ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p388ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p389ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p390ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p391ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p392ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p393ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p394ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p395ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p397ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p400a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2 OR MORE' ;
  VALUE p400a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' ;
  VALUE p400a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' ;
  VALUE p400a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' 5='(5) 100+' ;
  VALUE p400a11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2 OR MORE' ;
  VALUE p400a12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' ;
  VALUE p400a15f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6 OR MORE' ;
  VALUE p400a16f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6 OR MORE' ;
  VALUE p400a17f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-5' 3='(3) 6-20' 4='(4) 21-100' ;
  VALUE p402ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p404a21f  -9='(-9) LEGITIMATE SKIP' ;
  VALUE p408ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME' 2='(2) 2-3 TIMES' 3='(3) 4-10 TIMES'
                  4='(4) 11 OR MORE TIMES' ;
  VALUE p409ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME?' 2='(2) 2 OR MORE TIMES?' ;
  VALUE p410ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p411ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NOT ASKED OF ADULTS' ;
  VALUE p412ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p413ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 DAY OR LESS' 2='(2) 2-6 DAYS' 3='(3) 1-4 WEEKS' 4='(4) 1-3 MONTHS'
                  5='(5) 4-12 MONTHS' ;
  VALUE p415ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) RESPONDENT 26 OR OLDER' ;
  VALUE p416ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) RESPONDENT 26 OR OLDER' ;
  VALUE p417ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p418ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p419ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p420ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p423ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 5 OR MORE TIMES PER WEEK' 2='(2) 2-4 TIMES PER WEEK'
                  3='(3) ONCE A WEEK' 4='(4) 2-3 TIMES A MONTH'
                  5='(5) ONCE A MONTH OR LESS' 6='(6) NOT UNDER SUPERVISION' ;
  VALUE p425ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p426ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p428ffff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE p430ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 2='(2) NO' ;
  VALUE p431m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m12f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p431m15f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 2='(2) NO' ;
  VALUE p431m16f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p434ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p437a1ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES' -1='(-1) REFUSAL'
                  3='(3) SERVICE WORKER' 5='(5) SKILLED WORKER OR CRAFTSMEN'
                  14='(14) OTHER' ;
  VALUE p438a1ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES' 1='(1) YES'
                  2='(2) NO' ;
  VALUE p441a1ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 20 OR LESS' 2='(2) 21-35'
                  3='(3) 36-40' 4='(4) 40 OR MORE' ;
  VALUE p442a1ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-6 MONTHS' 3='(3) 7-12 MONTHS'
                  4='(4) MORE THAN 12 MONTHS' ;
  VALUE p441a2ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES'
                  -2='(-2) DON''T KNOW' 1='(1) 20 OR LESS' 2='(2) 21-35' 3='(3) 36-40'
                  4='(4) 40 OR MORE' ;
  VALUE p442a2ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES'
                  1='(1) LESS THAN 1 MONTH' 2='(2) 1-6 MONTHS' 3='(3) 7-12 MONTHS'
                  4='(4) MORE THAN 12 MONTHS' ;
  VALUE p445ffff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) YES' 2='(2) NO' ;
  VALUE p446ffff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES'
                  -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) YES' 2='(2) NO' ;
  VALUE p449a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  10='(10) JOB RELATED' 20='(20) FINANCIAL' 30='(30) CHILD CARE'
                  40='(40) TRANSPORTATION' 50='(50) FAMILY/FRIEND PROBLEMS'
                  70='(70) LEGAL BARRIER' 80='(80) SKILL/EXPERIENCE/EDUCATION'
                  100='(100) DRUG USE' 110='(110) ILLNESS/INJURY' 120='(120) OTHER' ;
  VALUE p450m1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 2='(2) NO' ;
  VALUE p450m7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p450m11f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p451ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CURRENTLY WORKING' ;
  VALUE p452ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' 4='(4) MORE THAN 12 MONTHS AGO'
                  5='(5) CURRENTLY WORKING' ;
  VALUE p453ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN ONE MONTH' 2='(2) 1-6 MONTHS' 3='(3) 7-12 MONTHS'
                  4='(4) MORE THAN 12 MONTHS' ;
  VALUE p454ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p456ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) CLERICAL WORKER' 2='(2) SALES WORKER' 3='(3) SERVICE WORKER'
                  4='(4) PRIVATE HOUSEHOLD WORKER'
                  5='(5) SKILLED WORKER OR CRAFTSMEN' 6='(6) LABORER'
                  7='(7) OPERATOR OR MACHINE OPERATOR' 14='(14) OTHER'
                  15='(15) INTERVIEWER UNABLE TO CODE' ;
  VALUE p460m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN 4.25' 2='(2) 4.25-10.00' 3='(3) MORE THAN 10.00' ;
  VALUE p460ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) PER HOUR' 2='(2) EVERY WEEK' 3='(3) EVERY TWO WEEKS'
                  4='(4) PER MONTH' 5='(5) PER YEAR' 6='(6) OTHER' ;
  VALUE p462ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE?' 2='(2) LESS THAN ONE MONTH?' 3='(3) 1-3 MONTHS?'
                  4='(4) 4-6 MONTHS?' 5='(5) 7-9 MONTHS?' 6='(6) 10-12 MONTHS?'
                  7='(7) MORE THAN 12 MONTHS?' ;
  VALUE p464ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p465ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE' 2='(2) 2-3' 3='(3) 4-10' 4='(4) 11 OR MORE' ;
  VALUE p466ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CHILDCARE NOT NECESSARY' ;
  VALUE p467ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) CHILDCARE NOT NECESSARY' ;
  VALUE p468ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p469ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p470ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p471ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) LESS THAN HALF' 2='(2) HALF OR MORE' 3='(3) ALL' ;
  VALUE p474a1ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES' 1='(1) YES'
                  2='(2) NO' ;
  VALUE p474a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p474a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p474a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p474a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p474a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p474a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p477m1ff  -9='(-9) NO CURRENT JOB' -7='(-7) NOT ASKED OF INMATES'
                  -6='(-6) NOT APPLICABLE' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) MALE, 3000 OR LESS' 2='(2) MALE, 3001-10,000'
                  3='(3) MALE, 10,001 OR MORE' 4='(4) FEMALE, 3000. OR LESS'
                  5='(5) FEMALE, 3001. OR MORE' ;
  VALUE p477m2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) MALE, 3000 OR LESS' 2='(2) MALE, 3001-10,000'
                  3='(3) MALE, 10,001 OR MORE' 4='(4) FEMALE, 3000. OR LESS'
                  5='(5) FEMALE, 3001. OR MORE' ;
  VALUE p479ffff  -9='(-9) LEGITIMATE SKIP' ;
  VALUE p481ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) EXCELLENT?' 2='(2) GOOD?' 3='(3) FAIR?' 4='(4) POOR?' ;
  VALUE p485a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a6ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a7ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a8ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a9ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p485a10f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p486ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p487ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p489ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NOT AT ALL' 2='(2) SOMEWHAT' 3='(3) VERY MUCH' ;
  VALUE p494a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-9' 4='(4) 10-25' 5='(5) 26-100' 6='(6) 101-500'
                  7='(7) MORE THAN 500' ;
  VALUE p495a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE p494a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2-9' 4='(4) 10 OR MORE' ;
  VALUE p495a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE p494a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2 OR MORE' ;
  VALUE p495a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE p494a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE' 3='(3) 2 OR MORE' ;
  VALUE p495a4ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE p494a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NONE' 2='(2) ONE OR MORE' ;
  VALUE p495a5ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) NEVER' 2='(2) LESS THAN 1/2' 3='(3) HALF OF THE TIME'
                  4='(4) MORE THAN 1/2' 5='(5) EVERY TIME' 6='(6) NO SUCH PARTNERS' ;
  VALUE p497ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p498ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p499ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p500ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p501ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p502ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p503ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) ONE TIME?' 2='(2) 2 OR MORE TIMES?' ;
  VALUE p508ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p509ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p510ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p512a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2' 3='(3) 3' 4='(4) 4' 5='(5) 5' 6='(6) 6-10' 11='(11) 11 OR MORE' ;
  VALUE p514a1ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p513a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 TIME?' 2='(2) 2-9 TIMES?' 3='(3) 10 TIMES OR MORE?' ;
  VALUE p514a2ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p513a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) 1 TIME?' 2='(2) 2-9 TIMES?' 3='(3) 10 TIMES OR MORE?' ;
  VALUE p514a3ff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p521ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE p522ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL' 1='(1) 1'
                  2='(2) 2 OR MORE' ;
  VALUE p524ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) WITHIN THE PAST MONTH' 2='(2) 1-6 MONTHS AGO'
                  3='(3) 7-12 MONTHS AGO' ;
  VALUE p525ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO BIRTHS' ;
  VALUE p526ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' 3='(3) NO BIRTHS' ;
  VALUE p528ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE (MALE)'
                  -5='(-5) NEVER' -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW'
                  -1='(-1) REFUSAL' 1='(1) YES' 2='(2) NO' ;
  VALUE p529ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) INCREASED OR STAYED ABOUT THE SAME' 2='(2) DECREASED' ;
  VALUE p530ffff  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
  VALUE pbeervol  -9='(-9) LEGITIMATE SKIP' ;
  VALUE pwinevol  -9='(-9) LEGITIMATE SKIP' ;
  VALUE pliquvol  -9='(-9) LEGITIMATE SKIP' ;
  VALUE in_4411f  -9='(-9) LEGITIMATE SKIP' -8='(-8) NOT ASKED OF MINORS'
                  -7='(-7) NOT ASKED OF INMATES' -6='(-6) NOT APPLICABLE' -5='(-5) NEVER'
                  -4='(-4) NONE' -3='(-3) MISSING' -2='(-2) DON''T KNOW' -1='(-1) REFUSAL'
                  1='(1) YES' 2='(2) NO' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=934;
INPUT
        CASEID 1-7              P4 8-9                  P5 10-11
        P7 12-13                P11 14-15               P13 16-17
        P26 18-19               P87 20-21               P88 22-23
        P92 24-25               P96 26-27               P102M1 28-29
        P102M2 30-31            P102M3 32-33            P102M4 34-35
        P114 36-37              P121 38-39              P130 40-41
        P135 42-46              PRGMTYPE 47-48          TRT2 49-50
        PRG2 51-52              CELL 53-54              CELL2 55-56
        P137 57-58              P138 59-60              P139M1 61-62
        P139M2 63-64            P139M3 65-66            P139M4 67-68
        P139M5 69-70            P139M6 71-72            P139M7 73-74
        P145 75-76              P146 77-78              P150 79-80
        P155 81-82              P159 83-84              P160 85-86
        P161 87-88              P162 89-90              P164 91-92
        P165 93-94              P166 95-98              P172A1 99-100
        P172A2 101-102          P172A3 103-104          P172A4 105-106
        P172A5 107-108          P172A6 109-110          P172A7 111-112
        P172A8 113-114          P172A9 115-116          P172A10 117-118
        P172A11 119-120         P172A12 121-122         P181A1 123-124
        P186A1 125-126          P187A1 127-128          P188A1 129-130
        P181A2 131-132          P186A2 133-134          P187A2 135-136
        P188A2 137-138          P181A3 139-140          P182A3 141-142
        P183A3 143-144          P186A3 145-146          P187A3 147-148
        P188A3 149-150          P181A4 151-152          P182A4 153-154
        P183A4 155-156          P186A4 157-158          P187A4 159-160
        P188A4 161-162          P181A5 163-164          P186A5 165-166
        P187A5 167-168          P188A5 169-170          P181A6 171-172
        P186A6 173-174          P187A6 175-176          P188A6 177-178
        P181A7 179-180          P186A7 181-182          P187A7 183-184
        P188A7 185-186          P181A8 187-188          P186A8 189-190
        P187A8 191-192          P188A8 193-194          P181A9 195-196
        P186A9 197-198          P187A9 199-200          P188A9 201-202
        P181A10 203-204         P186A10 205-206         P187A10 207-208
        P188A10 209-210         P181A11 211-212         P186A11 213-214
        P187A11 215-216         P188A11 217-218         P181A12 219-220
        P186A12 221-222         P187A12 223-224         P188A12 225-226
        P189 227-228            P190 229-230            P191 231-232
        P192 233-234            P193 235-236            P194 237-238
        P195 239-240            P196 241-242            P197 243-244
        P198 245-246            P199 247-248            P201 249-250
        P202 251-252            P203 253-254            P204 255-256
        P205 257-258            P206 259-260            P208A1 261-262
        P209A1 263-264          P210A1 265-266          P213A1 267-268
        P208A2 269-270          P209A2 271-272          P210A2 273-274
        P213A2 275-276          P208A3 277-278          P209A3 279-280
        P210A3 281-282          P221 283-284            P223 285-286
        P225 287-288            P227 289-290            P229 291-294
        P237 295-296            P238 297-298            P239 299-300
        P240 301-302            P241 303-304            P242 305-306
        P243 307-308            P244 309-310            P245 311-312
        P249A1 313-314          P250A1 315-316          P249A2 317-318
        P250A2 319-320          P249A3 321-322          P250A3 323-324
        P249A4 325-326          P250A4 327-328          P249A5 329-330
        P250A5 331-332          P249A6 333-334          P250A6 335-336
        P249A7 337-338          P250A7 339-340          P249A8 341-342
        P250A8 343-344          P249A9 345-346          P250A9 347-348
        P252 349-350            P254 351-352            P255 353-354
        P256 355-356            P257 357-358            P258 359-360
        P259 361-362            P262A1 363-364          P262A2 365-366
        P262A3 367-368          P262A4 369-370          P262A5 371-372
        P264A1 373-374          P266A1 375-376          P264A2 377-378
        P266A2 379-380          P264A3 381-382          P266A3 383-384
        P264A4 385-386          P266A4 387-388          P264A5 389-390
        P266A5 391-392          P267 393-394            P268M1 395-396
        P268M2 397-398          P268M3 399-400          P268M6 401-402
        P269 403-404            P270M1 405-406          P270M5 407-408
        P270M6 409-410          P271 411-412            P272M1 413-414
        P272M2 415-416          P272M3 417-418          P272M6 419-420
        P273 421-422            P274 423-424            P275 425-426
        P276 427-428            P278 429-430            P279 431-432
        P280 433-434            P281 435-436            P283 437-438
        P284 439-440            P285 441-442            P286 443-444
        P287 445-446            P289 447-448            P290 449-450
        P291 451-452            P292 453-454            P294 455-456
        P295 457-458            P296 459-460            P297 461-462
        P298 463-464            P299 465-466            P301 467-468
        P302 469-470            P303 471-472            P304 473-474
        P305 475-476            P306 477-478            P307 479-480
        P308 481-482            P309 483-484            P310 485-486
        P311 487-488            P312 489-490            P314 491-494
        P316 495-496            P317 497-498            P319 499-500
        P321 501-502            P323 503-504            P324 505-506
        P326 507-508            P332M1 509-510          P333A1 511-512
        P332M2 513-514          P333A2 515-516          P332M3 517-518
        P333A3 519-520          P332M4 521-522          P333A4 523-524
        P334 525-526            P335M1 527-528          P335M2 529-530
        P335M3 531-532          P336 533-534            P337 535-536
        P338 537-538            P342 539-540            P344 541-542
        P345 543-544            P346 545-546            P347 547-548
        P348 549-550            P350 551-552            P351 553-554
        P352 555-556            P353 557-558            P354 559-560
        P355 561-562            P356 563-564            P357 565-566
        P358 567-568            P359 569-570            P360 571-572
        P361 573-574            P362 575-576            P363 577-578
        P364 579-580            P365 581-582            P367 583-584
        P368 585-586            P369 587-588            P370 589-592
        P378 593-594            P379 595-596            P380 597-598
        P381 599-600            P382 601-602            P383 603-604
        P384 605-606            P385 607-608            P386 609-610
        P387 611-612            P388 613-614            P389 615-616
        P390 617-618            P391 619-620            P392 621-622
        P393 623-624            P394 625-626            P395 627-628
        P397 629-630            P400A2 631-632          P400A3 633-634
        P400A5 635-636          P400A10 637-638         P400A11 639-640
        P400A12 641-642         P400A15 643-644         P400A16 645-646
        P400A17 647-648         P402 649-650            P404A21 651-652
        P408 653-654            P409 655-656            P410 657-658
        P411 659-660            P412 661-662            P413 663-664
        P415 665-666            P416 667-668            P417 669-670
        P418 671-672            P419 673-674            P420 675-676
        P423 677-678            P425 679-680            P426 681-682
        P428 683-687            P430 688-689            P431M1 690-691
        P431M2 692-693          P431M3 694-695          P431M4 696-697
        P431M5 698-699          P431M6 700-701          P431M7 702-703
        P431M8 704-705          P431M9 706-707          P431M10 708-709
        P431M11 710-711         P431M12 712-713         P431M15 714-715
        P431M16 716-717         P434 718-719            P437A1 720-721
        P438A1 722-723          P441A1 724-725          P442A1 726-727
        P441A2 728-729          P442A2 730-731          P445 732-733
        P446 734-735            P449A1 736-738          P450M1 739-740
        P450M2 741-742          P450M3 743-744          P450M4 745-746
        P450M5 747-748          P450M6 749-750          P450M7 751-752
        P450M8 753-754          P450M9 755-756          P450M10 757-758
        P450M11 759-760         P451 761-762            P452 763-764
        P453 765-766            P454 767-768            P456 769-770
        P460M2 771-772          P460 773-774            P462 775-776
        P464 777-778            P465 779-780            P466 781-782
        P467 783-784            P468 785-786            P469 787-788
        P470 789-790            P471 791-792            P474A1 793-794
        P474A2 795-796          P474A3 797-798          P474A4 799-800
        P474A5 801-802          P474A6 803-804          P474A7 805-806
        P477M1 807-808          P477M2 809-810          P479 811-815
        P481 816-817            P485A1 818-819          P485A2 820-821
        P485A3 822-823          P485A4 824-825          P485A5 826-827
        P485A6 828-829          P485A7 830-831          P485A8 832-833
        P485A9 834-835          P485A10 836-837         P486 838-839
        P487 840-841            P489 842-843            P494A1 844-845
        P495A1 846-847          P494A2 848-849          P495A2 850-851
        P494A3 852-853          P495A3 854-855          P494A4 856-857
        P495A4 858-859          P494A5 860-861          P495A5 862-863
        P497 864-865            P498 866-867            P499 868-869
        P500 870-871            P501 872-873            P502 874-875
        P503 876-877            P508 878-879            P509 880-881
        P510 882-883            P512A1 884-885          P514A1 886-887
        P513A2 888-889          P514A2 890-891          P513A3 892-893
        P514A3 894-895          P521 896-897            P522 898-899
        P523 900-901            P524 902-903            P525 904-905
        P526 906-907            P528 908-909            P529 910-911
        P530 912-913            P532 914-918            P554 919-923
        PBEERVOL 924-926        PWINEVOL 927-929        PLIQUVOL 930-932
        IN_4411 933-934         ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'PATIENT ID'
   P4      = 'LAST SETTING'
   P5      = 'GENDER'
   P7      = 'LANGUAGE PREFERENCE'
   P11     = 'NTEQ COMPLETED?'
   P13     = 'NTEQ DISCHARGE STATUS: STILL IN TX?'
   P26     = 'AGE FROM BIRTH DATE'
   P87     = 'QTS2D DOB MATCH'
   P88     = 'CONTINUE INTERVIEW?'
   P92     = 'OUT OF CUSTODY SINCE NRIQ?.PA5'
   P96     = 'LENGTH OF CURRENT INCARCERATION.PA6'
   P102M1  = 'AWAITING TRIAL OR TRIAL PROCEEDINGS'
   P102M2  = 'AWAITING SENTENCING'
   P102M3  = 'SERVING A SENTENCE'
   P102M4  = 'SOMETHING ELSE'
   P114    = 'INTERVIEWER CHECKPOINT I'
   P121    = 'STOP DATE YR.PA11'
   P130    = 'IN OR OUT OF TREATMENT?.PA13'
   P135    = 'SECTION A ELAPSED TIME'
   PRGMTYPE= 'DENOTES DEMONSTRATION'
   TRT2    = 'INPATIENT AND RESIDENTIAL'
   PRG2    = 'ADOLESCENT/JUVENILE JUSTICE'
   CELL    = 'METHADONE SDUs'
   CELL2   = 'CATEGORIZED BY MODALITY'
   P137    = 'HIGHEST GRADE ATTENDED.PB1'
   P138    = 'S-S ATTENDED SCHOOL?.PB2'
   P139M1  = 'ELEMENTARY SCHOOL/MIDDLE SCHOOL/JUNIOR H'
   P139M2  = 'HIGH SCHOOL OR HIGH SCHOOL PROGRAM'
   P139M3  = 'GED PROGRAM'
   P139M4  = 'JUNIOR (2-YEAR) COLLEGE'
   P139M5  = '4-YEAR COLLEGE/UNIVERSITY'
   P139M6  = 'TECHNICAL/TRADE/VOCATIONAL SCHOOL'
   P139M7  = 'OTHER'
   P145    = 'S-S REC''D HS DIPLOMA/GED?.PB4'
   P146    = 'REC''D HS DIPLOMA OR GED.PB5'
   P150    = 'S-S REC''D ANY OTHER DIPLOMAS?.PB6'
   P155    = 'S-S REC''D ENGLISH LANGUAGE CLASSES?.PB8'
   P159    = 'CLASSES TO HELP TO READ.PB10'
   P160    = 'ABILITY TO READ ENGLISH.PB11'
   P161    = 'LAST SCHOOL GRADES.PB12'
   P162    = 'EVER EXPELLED FROM SCHOOL.PB13'
   P164    = 'EXPELLED MORE THAN ONE TIME.PB14'
   P165    = 'DRUGS CAUSED TO LEAVE SCHOOL.PB15'
   P166    = 'NPAQ_B ELAPSED TIME'
   P172A1  = 'DRUGS USED.INHALANTS'
   P172A2  = 'DRUGS USED.MARIJUANA'
   P172A3  = 'DRUGS USED.CRACK'
   P172A4  = 'DRUGS USED.COCAINE POWDER'
   P172A5  = 'DRUGS USED.PCP'
   P172A6  = 'DRUGS USED.HALLUCINOGENS'
   P172A7  = 'DRUGS USED.HEROIN'
   P172A8  = 'DRUGS USED.ILLEGAL METH'
   P172A9  = 'DRUGS USED.OTH NARCOTICS'
   P172A10 = 'DRUGS USED.UPPERS'
   P172A11 = 'DRUGS USED.DOWNERS'
   P172A12 = 'DRUGS USED.OTHER'
   P181A1  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?'
   P186A1  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A1  = 'LAST USED DRUG TYPE.PC7'
   P188A1  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A2  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A2  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A2  = 'LAST USED DRUG TYPE.PC7'
   P188A2  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A3  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P182A3  = 'USED CRACK/COCAINE 48 HOURS STRAIGHT?.PC'
   P183A3  = 'LAST USED CRACK/COCAINE 48 HOURS STRAIGH'
   P186A3  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A3  = 'LAST USED DRUG TYPE.PC7'
   P188A3  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A4  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P182A4  = 'USED CRACK/COCAINE 48 HOURS STRAIGHT?.PC'
   P183A4  = 'LAST USED CRACK/COCAINE 48 HOURS STRAIGH'
   P186A4  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A4  = 'LAST USED DRUG TYPE.PC7'
   P188A4  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A5  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A5  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A5  = 'LAST USED DRUG TYPE.PC7'
   P188A5  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A6  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A6  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A6  = 'LAST USED DRUG TYPE.PC7'
   P188A6  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A7  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A7  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A7  = 'LAST USED DRUG TYPE.PC7'
   P188A7  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A8  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A8  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A8  = 'LAST USED DRUG TYPE.PC7'
   P188A8  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A9  = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A9  = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A9  = 'LAST USED DRUG TYPE.PC7'
   P188A9  = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A10 = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A10 = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A10 = 'LAST USED DRUG TYPE.PC7'
   P188A10 = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A11 = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A11 = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A11 = 'LAST USED DRUG TYPE.PC7'
   P188A11 = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P181A12 = 'USED DRUG TYPE EVERY DAY FOR 2 WEEKS?.PC'
   P186A12 = 'MONTHS USED DRUG TYPE IN LAST 12.PC6'
   P187A12 = 'LAST USED DRUG TYPE.PC7'
   P188A12 = 'DAYS USED DRUG TYPE IN LAST 30.PC8'
   P189    = 'TROUBLED BY USE.PC9'
   P190    = 'HOSPITALIZED FOR OVERDOSE?.PC10'
   P191    = 'LAST OVERDOSED ON DRUGS.PC11'
   P192    = 'TIMES OVERDOSED IN LAST 12 MONTHS.PC12'
   P193    = 'CASH SPENT ON DRUGS LAST 30 DAYS.PC13'
   P194    = 'EVER INJECTED?.PC14'
   P195    = 'HAD DRUGS INJECTED?.PC15'
   P196    = 'LAST INJECTED DRUGS.PC16'
   P197    = 'DAYS INJECTED DRUGS IN LAST 30.PC17'
   P198    = 'SHARED NEEDLE OR WORKS?.PC18'
   P199    = 'LAST SHARED NEEDLE OR WORKS.PC19'
   P201    = 'HOW OFTEN SHARED NEEDLE LAST 30DYS/12MOS'
   P202    = 'HOW OFTEN CLEANED NDLE LAST 30DYS/12MOS.'
   P203    = 'HOW OFTEN SHARED WORKS LAST 30DYS/12MOS.'
   P204    = 'DAYS SHARED STRANGER''S NDLE/WRKS-30 DAYS'
   P205    = 'EVER HAD ALCOHOL DRINK?.PC24'
   P206    = 'DAYS DRANK ALCOHOL IN LAST 30.PC25'
   P208A1  = 'DAYS DRANK BEER IN LAST 30.PC26'
   P209A1  = 'BEER DRUNK EACH DAY OF LAST 30 DAYS'
   P210A1  = 'UNIT OF ALCOHOL.PC27B'
   P213A1  = 'VOLUME OF ALCOHOL UNIT.PC27C'
   P208A2  = 'DAYS DRANK WINE IN LAST 30.PC26'
   P209A2  = 'WINE DRUNK EACH DAY OF LAST 30 DAYS'
   P210A2  = 'UNIT OF ALCOHOL.PC27B'
   P213A2  = 'VOLUME OF ALCOHOL UNIT.PC27C'
   P208A3  = 'DAYS DRANK LIQUOR IN LAST 30.PC26'
   P209A3  = 'LIQUOR DRUNK EACH DAY OF LAST 30 DAYS'
   P210A3  = 'UNIT OF ALCOHOL.PC27B'
   P221    = 'DAYS GOTTEN DRUNK IN LAST 30.PC28'
   P223    = 'ALCOHOL DT''S?.PC29'
   P225    = 'HOSPITALIZED FOR DRINKING?.PC30'
   P227    = 'TROUBLED/BOTHERED BY OWN ALCOHOL USE.PC3'
   P229    = 'TIME STAMP'
   P237    = 'STAYED IN OWN APT 12 MONTHS?.D1A'
   P238    = 'STAYED IN OTHER''S APT 12 MONTHS?.D1B'
   P239    = 'STAYED IN HOTEL ROOM 12 MONTHS?.D1C'
   P240    = 'STAYED IN HOMELESS SHELTER 12 MONTHS?.D1'
   P241    = 'STAYED IN OTHER SHELTER 12 MONTHS?.D1E'
   P242    = 'STAYED IN HOSPITAL 12 MONTHS?.D1F'
   P243    = 'STAYED IN JAIL 12 MONTHS?.D1G'
   P244    = 'STAYED IN GROUP HOME 12 MONTHS?.D1H'
   P245    = 'STAYED IN OTHER PLACE 12 MONTHS?.D1I'
   P249A1  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A1  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A2  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A2  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A3  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A3  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A4  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A4  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A5  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A5  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A6  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A6  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A7  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A7  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A8  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A8  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P249A9  = 'TIME SPENT IN PLACE LAST 12 MONTHS.PD2'
   P250A9  = 'STAYED IN PLACE IN 30 DAYS.PD3'
   P252    = 'PLACE STAYED LAST NIGHT (CODE).PD4_1'
   P254    = 'STAYED IN PUBLIC HOUSING LAST NIGHT?.PD5'
   P255    = 'SAW DRUG USE/SALE NEAR HOME LAST 7 DAYS?'
   P256    = 'APPROACHED TO USE/BUY DRUGS LAST 7 DAYS?'
   P257    = 'SHOOTING/KNIFING NEARBY PAST 7DYS?.PD8'
   P258    = 'MUGGING/BEATING NEARBY PAST 7DYS?.PD9'
   P259    = 'KNOWN PEOPLE KILLED LAST 12MO.PD10'
   P262A1  = 'LIVED WITH SPOUSE LAST 12 MONTHS?.PD11'
   P262A2  = 'LIVED WITH MOTHER LAST 12 MONTHS?.PD11'
   P262A3  = 'LIVED WITH FATHER LAST 12 MONTHS?.PD11'
   P262A4  = 'LIVED WITH KIDS<18 LAST 12 MONTHS?.PD11'
   P262A5  = 'LIVED WITH KIDS>18 LAST 12 MONTHS?.PD11'
   P264A1  = 'TIME LIVED WITH PERSON LAST 12 MONTHS.PD'
   P266A1  = 'CURRENTLY LIVING WITH PERSON?.PD13'
   P264A2  = 'TIME LIVED WITH PERSON LAST 12 MONTHS.PD'
   P266A2  = 'CURRENTLY LIVING WITH PERSON?.PD13'
   P264A3  = 'TIME LIVED WITH PERSON LAST 12 MONTHS.PD'
   P266A3  = 'CURRENTLY LIVING WITH PERSON?.PD13'
   P264A4  = 'TIME LIVED WITH PERSON LAST 12 MONTHS.PD'
   P266A4  = 'CURRENTLY LIVING WITH PERSON?.PD13'
   P264A5  = 'TIME LIVED WITH PERSON LAST 12 MONTHS.PD'
   P266A5  = 'CURRENTLY LIVING WITH PERSON?.PD13'
   P267    = 'CURRENTLY LIVING WITH ALCOHOLIC?.PD14'
   P268M1  = 'SPOUSE OR PARTNER'
   P268M2  = 'MOTHER OR FEMALE GUARDIAN'
   P268M3  = 'FATHER OR MALE GUARDIAN'
   P268M6  = 'OTHER PERSON'
   P269    = 'CURRENTLY LIVING WITH DRUG USER?.PD16'
   P270M1  = 'SPOUSE/MOTHER/FATHER'
   P270M5  = 'RS CHILD >= 18'
   P270M6  = 'OTHER PERSON'
   P271    = 'CURRENTLY LIVING WITH 12-STEP GOER?.PD18'
   P272M1  = 'SPOUSE'
   P272M2  = 'MOTHER'
   P272M3  = 'FATHER'
   P272M6  = 'OTHER PERSON'
   P273    = 'NON-COHABITANT PARTNER?.PD20'
   P274    = 'PARTNER ABUSING ALCOHOL?.PD21'
   P275    = 'PARTNER USING DRUGS?.PD22'
   P276    = 'PARTNER IN 12-STEP/TREATMENT?.PD23'
   P278    = 'CHILDREN NOW RAISING.PD24'
   P279    = 'AFRAID OF LOSING CUSTODY?.PD25'
   P280    = 'CURRENTLY MARRIED?.PD26'
   P281    = 'EVER MARRIED?.PD27'
   P283    = 'LIVE WITH SPOUSE?.PD28'
   P284    = 'LENGTH OF MARITAL SEPARATION.PD29'
   P285    = 'NUMBER OF DEPENDENTS.PD30'
   P286    = 'PERSON TO CONFIDE IN?.PD31'
   P287    = 'EMERGENCY SUPPORT PERSON?.PD32'
   P289    = 'AGE MET SUPPORT PERSON 1.PD33A'
   P290    = 'AGE MET SUPPORT PERSON 2.PD33B'
   P291    = 'AGE MET SUPPORT PERSON 3.PD33C'
   P292    = 'EVER OUTPLACED BY COURTS/AGENCY?.PD34'
   P294    = 'EVER RUN AWAY FROM HOME?.PD35'
   P295    = 'EVER KICKED OUT BY PARENT/GUARDIAN?.PD36'
   P296    = 'EVER ATTACKED?.PD37'
   P297    = 'BEATEN?.PD38'
   P298    = 'TIMES ATTACKED/BEATEN.PD39'
   P299    = 'WHEN LAST ATTACKED.PD40'
   P301    = 'EVER BEATEN BY SPOUSE/PARTNER?.PD41'
   P302    = 'S-S REC''D PARENTING TRAINING.PD42'
   P303    = '# TIMES RECEIVED PARENTING TRAINING.PD43'
   P304    = 'S-S REC''D SERVICES FOR ABUSED?.PD44'
   P305    = '# OF SESSIONS FOR ABUSED ATTENDED?.PD45'
   P306    = 'S-S REC''D SERVS FOR OTHER FAMILY PROBS?.'
   P307    = '# TIMES REC''D OTHER FAMILY PROBS SERVS.P'
   P308    = 'S-S REC''D ASSERTIVENESS TRAINING?.PD48'
   P309    = '# TIMES ATTENDED ASSERT TRNG.PD49'
   P310    = 'S-S REC''D LIFE SKILLS TRNG?.PD50'
   P311    = '# LIFE SKILLS TRNG SESSIONS ATTENDED?.PD'
   P312    = 'S-S REC''D SERVICES FOR TEENS?.PD52'
   P314    = 'SECTION D ELAPSED TIME'
   P316    = 'PRIOR TREATMENT?.PE1'
   P317    = 'PRIOR DRUG TREATMENT?.PE2'
   P319    = 'NUMBER OF PRIOR TREATMENTS.PE3'
   P321    = 'TIME IN TREATMENT.PE5'
   P323    = 'MODALITY OF LONGEST TREATMENT.PE6'
   P324    = 'HELPFULLNESS OF LONGEST TX.PE7'
   P326    = 'ANY TREATMENT PROVIDERS SINCE STOP DATE.'
   P332M1  = 'INPATIENT'
   P333A1  = 'HELPFULLNESS OF TX.PE10'
   P332M2  = 'RESIDENTIAL'
   P333A2  = 'HELPFULLNESS OF TX.PE10'
   P332M3  = 'OUTPATIENT'
   P333A3  = 'HELPFULLNESS OF TX.PE10'
   P332M4  = 'METHADONE'
   P333A4  = 'HELPFULLNESS OF TX.PE10'
   P334    = 'ATTENDED 12 STEP?.PE11'
   P335M1  = 'ALCOHOL ANONYMOUS'
   P335M2  = 'NARCOTICS ANONYMOUS'
   P335M3  = 'COCAINE ANONYMOUS'
   P336    = 'ATTENDED 5+ MEETINGS LAST 12 MONTHS?.PE1'
   P337    = 'HELPFULLNESS OF 12 STEP MEETING.PE14'
   P338    = 'S-S TOOK MEDICINES FOR DRUG/ALC PROBS?.P'
   P342    = 'LEVEL OF METHODONE PRESCRIBED.PE17'
   P344    = '24 HOUR MENTAL HEALTH VISIT? .PE18'
   P345    = '# OF 24 HR MENTAL HEALTH VISITS.PE19'
   P346    = 'OUTPATIENT MENTAL HEALTH TREATMENT?.PE20'
   P347    = '# OF MHEALTH VISITS LAST 12 MOS.E5B'
   P348    = 'PSYCHOTROPIC DRUGS TAKEN LAST 7 DAYS?.PE'
   P350    = 'SUDDEN FEAR W/OUT DANGER? .PE23'
   P351    = 'SUDDEN IRRATIONAL FEAR? .PE24'
   P352    = 'DRUG-INDUCED SUDDEN FEAR.PE25'
   P353    = 'TREMBLING WHEN FRIGHTENED?.PE26A'
   P354    = 'SWEATING WHEN FRIGHTENED?.PE26B'
   P355    = 'TROUBLE BREATHING WHEN FRIGHTENED?.PE26C'
   P356    = 'HEART POUNDING WHEN FRIGHTENED?.PE26D'
   P357    = 'SEVERELY DEPRESSED FOR TWO WEEKS?.PE27'
   P358    = 'LOST INTEREST IN LIFE FOR 2 WEEKS?.PE28'
   P359    = 'DRUG-INDUCED 2 WEEK PERIODS.PE29'
   P360    = 'ATTEMPTED SUICIDE?.PE30'
   P361    = 'SUICIDE ATTEMPTED MORE THAN ONCE?.PE31'
   P362    = 'DRUG-INDUCED SUICIDE ATTEMPT?.PE32'
   P363    = 'DRUG-INDUCED SUICIDE ATTEMPTS.PE33'
   P364    = 'SUICIDAL THOUGHTS?.PE34'
   P365    = 'DRUG-INDUCED SUICIDAL THOUGHTS.PE35'
   P367    = 'HAD HALLUCINATIONS?.PE36'
   P368    = 'DRUG-INDUCED HALLUCINATIONS.PE37'
   P369    = 'TROUBLED/BOTHERED BY MENTAL HEALTH.PE38'
   P370    = 'SECTION E ELAPSED TIME'
   P378    = 'CRIMINAL ACTIVITY?.DRIVEN DRUNK/HIGH.PF1'
   P379    = 'EVER STOLE A VEHICLE.PF1B'
   P380    = 'EVER SOLD DRUGS.PF1C'
   P381    = 'GOT CUSTOMERS FOR PROSTITUTES.PF1D'
   P382    = 'EVER HAD SEX FOR MONEY/DRUGS.PF1E'
   P383    = 'EVER PASSED BAD/STOLEN CHECKS/CREDIT CAR'
   P384    = 'EVER WORKED IN BOOKMAKING.PF1G'
   P385    = 'EVER EMBEZZLED.PF1H'
   P386    = 'EVER BOUGHT STOLEN GOODS.PF1I'
   P387    = 'SHOPLIFTED.PF1J'
   P388    = 'BROKE INTO HOUSE,ETC.PF1K'
   P389    = 'USED WEAPON/FORCE TO STEAL.PF1L'
   P390    = 'SET FIRE TO BUILDING/VEHICLE.PF1M'
   P391    = 'DESTROYED PROPERTY.PF1N'
   P392    = 'ATTACKED/THREATENED SOMEONE.PF1O'
   P393    = 'BEATEN SOMEONE UP.PF1P'
   P394    = 'SEVERELY HURT SOMEONE.PF1Q'
   P395    = 'FORCED SEX ON SOMEONE.PF1R'
   P397    = 'COMMITTED OTHER OFFENSE.PF1T1'
   P400A2  = 'TIMES STOLE A VEHICLE'
   P400A3  = 'TIMES SOLD DRUGS'
   P400A5  = 'TIMES HAD SEX FOR MONEY/DRUGS'
   P400A10 = 'TIMES SHOPLIFTED'
   P400A11 = 'TIMES BROKE INTO HOUSE,ETC'
   P400A12 = 'TIMES USED WEAPON/FORCE TO STEAL'
   P400A15 = 'TIMES ATTACKED/THREATENED SOMEONE'
   P400A16 = 'TIMES BEAT SOMEONE UP'
   P400A17 = 'TIMES SEVERELY HURT SOMEONE'
   P402    = 'BELONGED TO A GANG IN 12 MOS?.PF3'
   P404A21 = 'ARRESTED FOR OTHER.PF4'
   P408    = 'TIMES ARRESTED.PF5'
   P409    = 'TIMES CONVICTED.PF6'
   P410    = 'ANY CONVICTIONS.PF7'
   P411    = 'EVER IN JUVENILE FACILITY.PF8'
   P412    = 'EVER KEPT IN JAIL 24+ HOURS.PF9'
   P413    = 'LENGTH OF PRISON/JAIL STAY.PF10'
   P415    = 'UNDER JUVENILE PROBATION.PF11_1'
   P416    = 'UNDER JUVENILE PAROLE.PF11_2'
   P417    = 'UNDER ADULT PROBATION.PF11_3'
   P418    = 'UNDER ADULT PAROLE.PF11_4'
   P419    = 'UNDER WORK RELEASE.PF11_5'
   P420    = 'UNDER OTHER SUPERVISION.PF11_6'
   P423    = 'HOW OFTEN TALK TO OFFICER.PF12'
   P425    = 'CRIMINAL CHARGES.PF13'
   P426    = 'OUTSTANDING WARRANTS.PF14'
   P428    = 'ELAPSED TIME SECTION F'
   P430    = 'EVER SUPPORTED BY ILLEGAL ACTIVITY?.PG1'
   P431M1  = 'DRUG DEALING'
   P431M2  = 'MOONSHINING, BOOT LEGGING, RUNNING LIQUO'
   P431M3  = 'PROSTITUTION'
   P431M4  = 'PIMPING/PROCURING'
   P431M5  = 'FORGERY/PASSING BAD CHECKS/CREDIT CARD F'
   P431M6  = 'BOOKMAKING/NUMBERS/GAMBLING'
   P431M7  = 'RECEIVING/POSSESSION OF STOLEN GOODS'
   P431M8  = 'MOTOR VEHICLE THEFT'
   P431M9  = 'SHOPLIFTING'
   P431M10 = 'BREAKING AND ENTERING/BURGLARY'
   P431M11 = 'ARMED ROBBERY/ROBBERY BY FORCE'
   P431M12 = 'OTHER THEFT (LARCENY/PICK POCKETING/PURS'
   P431M15 = 'MURDER'
   P431M16 = 'OTHER ILLEGAL ACTIVITY'
   P434    = 'CURRENTLY EMPLOYED?.PG4'
   P437A1  = 'TYPE OF JOB.PG5A'
   P438A1  = 'ANOTHER JOB?.PG6'
   P441A1  = 'HOURS WORKED AT JOB.PG7'
   P442A1  = 'HOW LONG AT JOB.PG8'
   P441A2  = 'HOURS WORKED AT JOB.PG7'
   P442A2  = 'HOW LONG AT JOB.PG8'
   P445    = 'SAW DRUG USE/SALE NEAR JOB LAST 7 DAYS?.'
   P446    = 'OFFERED DRUGS NEAR WORK LAST 7 DAYS?.PG1'
   P449A1  = 'G12S-CAPI SUMMARY CODE FRAME-REASONS NOT WORKING'
   P450M1  = 'REASON FOR NOT WORKING F/T - JOB RELATED'
   P450M2  = 'REASON FOR NOT WORKING F/T - FINANCIAL'
   P450M3  = 'REASON FOR NOT WORKING F/T - CHILD CARE'
   P450M4  = 'REASON FOR NOT WORKING F/T - TRANSPORTAT'
   P450M5  = 'REASON FOR NOT WORKING F/T - FAMILY/FRIE'
   P450M6  = 'REASON FOR NOT WORKING F/T - RACE/ETHNIC'
   P450M7  = 'REASON FOR NOT WORKING F/T - LEGAL BARRI'
   P450M8  = 'REASON FOR NOT WORKING F/T - SKILL/EXPER'
   P450M9  = 'REASON FOR NOT WORKING F/T - DRUG USE'
   P450M10 = 'REASON FOR NOT WORKING F/T - ILLNESS/INJ'
   P450M11 = 'REASON FOR NOT WORKING F/T - OTHER'
   P451    = 'HAD F/T JOB IN REF PERIOD?.PG12'
   P452    = 'TIME SINCE LAST F/T JOB.PG13'
   P453    = 'LONGEST TIME HELD F/T JOB.PG14'
   P454    = 'CURRENTLY AT LONGEST HELD JOB?.PG15'
   P456    = 'TYPE OF JOB-CODE.PG17'
   P460M2  = 'WAGE RATE - HOURLY'
   P460    = 'RATE OF PAY AT LONGEST JOB-RATE.PG18_3'
   P462    = 'MONTHS WORKED IN LAST 12.PG19'
   P464    = 'S-S REC''D JOB SKILLS SERVICES?.PG20'
   P465    = '# SESSIONS ATTENDED FOR JOB SKILLS.PG21'
   P466    = 'S-S REC''D CHILD CARE HELP?.PG22'
   P467    = 'UNABLE TO WORK FOR LACK OF CHILDCARE?.PG'
   P468    = 'S-S HELP WITH TRANSPORTATION?.PG24'
   P469    = 'R ABLE TO GET TO WK WITH TRANS HELP?.PG2'
   P470    = 'LIVED WITH SUPPORTER LAST 12 MONTHS?.PG2'
   P471    = 'HOW MUCH SUPPORTED BY PERSON LIVED WITH.'
   P474A1  = 'INCOME SRCE 12 MO: WAGES/SALARY.PG28'
   P474A2  = 'INCOME SRCE 12 MO: ALIMONY/SUPPRT.PG28'
   P474A3  = 'INCOME SRCE 12 MO: $ FROM SPOUSE.PG28'
   P474A4  = 'INCOME SRCE 12 MO: WELFARE.PG28'
   P474A5  = 'INCOME SRCE 12 MO: UNEMP/DISABILITY.PG28'
   P474A6  = 'INCOME SRCE 12 MO: SOC SECURITY.PG28'
   P474A7  = 'INCOME SRCE 12 MO: OTHER.PG28'
   P477M1  = 'INCOME - FROM OWN WAGES AND SALARIES'
   P477M2  = 'INCOME - FROM OTHER SOURCES'
   P479    = 'ELAPSED TIME SECTION G'
   P481    = 'GENERAL HEALTH.PH1'
   P485A1  = 'ILLNESSES SUFFERED-SIGHT.PH2'
   P485A2  = 'ILLNESSES SUFFERED-HEARING.PH2'
   P485A3  = 'ILLNESSES SUFFERED-TB.PH2'
   P485A4  = 'ILLNESSES SUFFERED-RESPIRATORY.PH2'
   P485A5  = 'ILLNESSES SUFFERED-HEART.PH2'
   P485A6  = 'ILLNESSES SUFFERED-HEPATITIS.PH2'
   P485A7  = 'ILLNESSES SUFFERED-INTERNAL COND.PH2'
   P485A8  = 'ILLNESSES SUFFERED-BONE/MUSCLE.PH2'
   P485A9  = 'ILLNESSES SUFFERED-NERVE.PH2'
   P485A10 = 'ILLNESSES SUFFERED-STD.PH2'
   P486    = 'R DIAGNOSED WITH  AIDS.PH3'
   P487    = 'OTHER HEALTH PROBLEM.PH4'
   P489    = 'HEALTH LIMITS ON WORK.PH6'
   P494A1  = '# HETEROSEX PARTNERS VAGINAL.PH7'
   P495A1  = 'CONDOM USE - HETEROSEXUAL INTERCOURSE.PH'
   P494A2  = '# HETEROSEX PARTNERS ORAL.PH7'
   P495A2  = 'CONDOM USE - HETEROSEXUAL ORAL SEX.PH'
   P494A3  = '# HETEROSEX PARTNERS ANAL.PH7'
   P495A3  = 'CONDOM USE - HETEROSEXUAL ANAL INTERCOUR'
   P494A4  = '# HOMOSEX PARTNERS ORAL.PH7'
   P495A4  = 'CONDOM USE - HOMOSEXUAL ORAL INTERCOURSE'
   P494A5  = '# HOMOSEX PARTNERS ANAL.PH7'
   P495A5  = 'CONDOM USE - HOMOSEXUAL ANAL INTERCOURSE'
   P497    = 'GOT THINGS FOR SEX.PH11'
   P498    = 'GAVE THINGS FOR SEX.PH12'
   P499    = 'HAD SEX WITH IV DRUG USER.PH13'
   P500    = 'KNEW SEX PARTNER HAD AIDS.PH14'
   P501    = 'LEARNED SEX PARTNER HAS AIDS.PH15'
   P502    = 'EVER FORCED TO HAVE SEX.PH16'
   P503    = 'TIMES FORCED TO HAVE SEX.PH17'
   P508    = 'ANY VISITS TO HOSPITAL LAST YEAR.PH18A'
   P509    = 'ANY VISITS TO EMERGENCY RM LAST YEAR.PH1'
   P510    = 'ANY VISITS TO CLINIC LAST YEAR.PH18C'
   P512A1  = 'NUMBER OF NIGHTS IN HOSPITAL.PH19'
   P514A1  = 'DRUGS/ALCOHOL CAUSED MEDICAL VISIT.PH21'
   P513A2  = 'NUMBER OF MEDICAL VISITS.PH20'
   P514A2  = 'DRUGS/ALCOHOL CAUSED MEDICAL VISIT.PH21'
   P513A3  = 'NUMBER OF MEDICAL VISITS.PH20'
   P514A3  = 'DRUGS/ALCOHOL CAUSED MEDICAL VISIT.PH21'
   P521    = 'EVER BEEN PREGNANT?.PH22'
   P522    = 'TIMES PREGNANT.PH23'
   P523    = 'TIMES GAVE BIRTH.PH24'
   P524    = 'DATE OF LAST LIVE BIRTH.PH25'
   P525    = 'DRUG USE DURING PRIOR PREGNANCY.PH26'
   P526    = 'BABIES TESTED FOR AIDS.PH27'
   P528    = 'R CURRENTLY PREGNANT.PH29'
   P529    = 'DRUG USE DURING CURRENT PREGNANCY.PH30'
   P530    = 'PRENATAL CARE RECEIVED.PH31'
   P532    = 'SECTION H ELAPSED TIME'
   P554    = 'SECTION K ELAPSED TIME'
   PBEERVOL= 'OUNCES BEER DRUNK USUAL DAY'
   PWINEVOL= 'OUNCES WINE DRUNK USUAL DAY'
   PLIQUVOL= 'OUNCES LIQUOR DRUNK USUAL DAY'
   IN_4411 = 'IN SUBSET OF 4,411 CASES'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (P4 <= -1) THEN P4 = .;
   IF (P5 <= -1) THEN P5 = .;
   IF (P7 <= -1) THEN P7 = .;
   IF (P11 <= -1) THEN P11 = .;
   IF (P13 <= -1) THEN P13 = .;
   IF (P26 <= -1) THEN P26 = .;
   IF (P87 <= -1) THEN P87 = .;
   IF (P88 <= -1) THEN P88 = .;
   IF (P92 <= -1) THEN P92 = .;
   IF (P96 <= -1) THEN P96 = .;
   IF (P102M1 <= -1) THEN P102M1 = .;
   IF (P102M2 <= -1) THEN P102M2 = .;
   IF (P102M3 <= -1) THEN P102M3 = .;
   IF (P102M4 <= -1) THEN P102M4 = .;
   IF (P114 <= -1) THEN P114 = .;
   IF (P121 <= -1) THEN P121 = .;
   IF (P130 <= -1) THEN P130 = .;
   IF (P135 <= -1) THEN P135 = .;
   IF (PRGMTYPE <= -1) THEN PRGMTYPE = .;
   IF (TRT2 <= -1) THEN TRT2 = .;
   IF (PRG2 <= -1) THEN PRG2 = .;
   IF (CELL <= -1) THEN CELL = .;
   IF (CELL2 <= -1) THEN CELL2 = .;
   IF (P137 <= -1) THEN P137 = .;
   IF (P138 <= -1) THEN P138 = .;
   IF (P139M1 <= -1) THEN P139M1 = .;
   IF (P139M2 <= -1) THEN P139M2 = .;
   IF (P139M3 <= -1) THEN P139M3 = .;
   IF (P139M4 <= -1) THEN P139M4 = .;
   IF (P139M5 <= -1) THEN P139M5 = .;
   IF (P139M6 <= -1) THEN P139M6 = .;
   IF (P139M7 <= -1) THEN P139M7 = .;
   IF (P145 <= -1) THEN P145 = .;
   IF (P146 <= -1) THEN P146 = .;
   IF (P150 <= -1) THEN P150 = .;
   IF (P155 <= -1) THEN P155 = .;
   IF (P159 <= -1) THEN P159 = .;
   IF (P160 <= -1) THEN P160 = .;
   IF (P161 <= -1) THEN P161 = .;
   IF (P162 <= -1) THEN P162 = .;
   IF (P164 <= -1) THEN P164 = .;
   IF (P165 <= -1) THEN P165 = .;
   IF (P166 <= -1) THEN P166 = .;
   IF (P172A1 <= -1) THEN P172A1 = .;
   IF (P172A2 <= -1) THEN P172A2 = .;
   IF (P172A3 <= -1) THEN P172A3 = .;
   IF (P172A4 <= -1) THEN P172A4 = .;
   IF (P172A5 <= -1) THEN P172A5 = .;
   IF (P172A6 <= -1) THEN P172A6 = .;
   IF (P172A7 <= -1) THEN P172A7 = .;
   IF (P172A8 <= -1) THEN P172A8 = .;
   IF (P172A9 <= -1) THEN P172A9 = .;
   IF (P172A10 <= -1) THEN P172A10 = .;
   IF (P172A11 <= -1) THEN P172A11 = .;
   IF (P172A12 <= -1) THEN P172A12 = .;
   IF (P181A1 <= -1) THEN P181A1 = .;
   IF (P186A1 <= -1) THEN P186A1 = .;
   IF (P187A1 <= -1) THEN P187A1 = .;
   IF (P188A1 <= -1) THEN P188A1 = .;
   IF (P181A2 <= -1) THEN P181A2 = .;
   IF (P186A2 <= -1) THEN P186A2 = .;
   IF (P187A2 <= -1) THEN P187A2 = .;
   IF (P188A2 <= -1) THEN P188A2 = .;
   IF (P181A3 <= -1) THEN P181A3 = .;
   IF (P182A3 <= -1) THEN P182A3 = .;
   IF (P183A3 <= -1) THEN P183A3 = .;
   IF (P186A3 <= -1) THEN P186A3 = .;
   IF (P187A3 <= -1) THEN P187A3 = .;
   IF (P188A3 <= -1) THEN P188A3 = .;
   IF (P181A4 <= -1) THEN P181A4 = .;
   IF (P182A4 <= -1) THEN P182A4 = .;
   IF (P183A4 <= -1) THEN P183A4 = .;
   IF (P186A4 <= -1) THEN P186A4 = .;
   IF (P187A4 <= -1) THEN P187A4 = .;
   IF (P188A4 <= -1) THEN P188A4 = .;
   IF (P181A5 <= -1) THEN P181A5 = .;
   IF (P186A5 <= -1) THEN P186A5 = .;
   IF (P187A5 <= -1) THEN P187A5 = .;
   IF (P188A5 <= -1) THEN P188A5 = .;
   IF (P181A6 <= -1) THEN P181A6 = .;
   IF (P186A6 <= -1) THEN P186A6 = .;
   IF (P187A6 <= -1) THEN P187A6 = .;
   IF (P188A6 <= -1) THEN P188A6 = .;
   IF (P181A7 <= -1) THEN P181A7 = .;
   IF (P186A7 <= -1) THEN P186A7 = .;
   IF (P187A7 <= -1) THEN P187A7 = .;
   IF (P188A7 <= -1) THEN P188A7 = .;
   IF (P181A8 <= -1) THEN P181A8 = .;
   IF (P186A8 <= -1) THEN P186A8 = .;
   IF (P187A8 <= -1) THEN P187A8 = .;
   IF (P188A8 <= -1) THEN P188A8 = .;
   IF (P181A9 <= -1) THEN P181A9 = .;
   IF (P186A9 <= -1) THEN P186A9 = .;
   IF (P187A9 <= -1) THEN P187A9 = .;
   IF (P188A9 <= -1) THEN P188A9 = .;
   IF (P181A10 <= -1) THEN P181A10 = .;
   IF (P186A10 <= -1) THEN P186A10 = .;
   IF (P187A10 <= -1) THEN P187A10 = .;
   IF (P188A10 <= -1) THEN P188A10 = .;
   IF (P181A11 <= -1) THEN P181A11 = .;
   IF (P186A11 <= -1) THEN P186A11 = .;
   IF (P187A11 <= -1) THEN P187A11 = .;
   IF (P188A11 <= -1) THEN P188A11 = .;
   IF (P181A12 <= -1) THEN P181A12 = .;
   IF (P186A12 <= -1) THEN P186A12 = .;
   IF (P187A12 <= -1) THEN P187A12 = .;
   IF (P188A12 <= -1) THEN P188A12 = .;
   IF (P189 <= -1) THEN P189 = .;
   IF (P190 <= -1) THEN P190 = .;
   IF (P191 <= -1) THEN P191 = .;
   IF (P192 <= -1) THEN P192 = .;
   IF (P193 <= -1) THEN P193 = .;
   IF (P194 <= -1) THEN P194 = .;
   IF (P195 <= -1) THEN P195 = .;
   IF (P196 <= -1) THEN P196 = .;
   IF (P197 <= -1) THEN P197 = .;
   IF (P198 <= -1) THEN P198 = .;
   IF (P199 = 5) THEN P199 = .;
   IF (P199 <= -1) THEN P199 = .;
   IF (P201 = 7) THEN P201 = .;
   IF (P201 <= -1) THEN P201 = .;
   IF (P202 = 7) THEN P202 = .;
   IF (P202 <= -1) THEN P202 = .;
   IF (P203 = 7) THEN P203 = .;
   IF (P203 <= -1) THEN P203 = .;
   IF (P204 = -2 OR P204 = 4 OR P204 = 5) THEN P204 = .;
   IF (P205 <= -1) THEN P205 = .;
   IF (P206 <= -1) THEN P206 = .;
   IF (P208A1 <= -1) THEN P208A1 = .;
   IF (P209A1 <= -1) THEN P209A1 = .;
   IF (P210A1 <= -1) THEN P210A1 = .;
   IF (P213A1 <= -1) THEN P213A1 = .;
   IF (P208A2 <= -1) THEN P208A2 = .;
   IF (P209A2 <= -1) THEN P209A2 = .;
   IF (P210A2 <= -1) THEN P210A2 = .;
   IF (P213A2 <= -1) THEN P213A2 = .;
   IF (P208A3 <= -1) THEN P208A3 = .;
   IF (P209A3 <= -1) THEN P209A3 = .;
   IF (P210A3 <= -1) THEN P210A3 = .;
   IF (P221 <= -1) THEN P221 = .;
   IF (P223 <= -1) THEN P223 = .;
   IF (P225 <= -1) THEN P225 = .;
   IF (P227 <= -1) THEN P227 = .;
   IF (P229 <= -1) THEN P229 = .;
   IF (P237 <= -1) THEN P237 = .;
   IF (P238 <= -1) THEN P238 = .;
   IF (P239 <= -1) THEN P239 = .;
   IF (P240 <= -1) THEN P240 = .;
   IF (P241 <= -1) THEN P241 = .;
   IF (P242 <= -1) THEN P242 = .;
   IF (P243 <= -1) THEN P243 = .;
   IF (P244 <= -1) THEN P244 = .;
   IF (P245 <= -1) THEN P245 = .;
   IF (P249A1 <= -1) THEN P249A1 = .;
   IF (P250A1 <= -1) THEN P250A1 = .;
   IF (P249A2 <= -1) THEN P249A2 = .;
   IF (P250A2 <= -1) THEN P250A2 = .;
   IF (P249A3 <= -1) THEN P249A3 = .;
   IF (P250A3 <= -1) THEN P250A3 = .;
   IF (P249A4 <= -1) THEN P249A4 = .;
   IF (P250A4 <= -1) THEN P250A4 = .;
   IF (P249A5 <= -1) THEN P249A5 = .;
   IF (P250A5 <= -1) THEN P250A5 = .;
   IF (P249A6 <= -1) THEN P249A6 = .;
   IF (P250A6 <= -1) THEN P250A6 = .;
   IF (P249A7 <= -1) THEN P249A7 = .;
   IF (P250A7 <= -1) THEN P250A7 = .;
   IF (P249A8 <= -1) THEN P249A8 = .;
   IF (P250A8 <= -1) THEN P250A8 = .;
   IF (P249A9 <= -1) THEN P249A9 = .;
   IF (P250A9 <= -1) THEN P250A9 = .;
   IF (P252 <= -1) THEN P252 = .;
   IF (P254 <= -1) THEN P254 = .;
   IF (P255 <= -1) THEN P255 = .;
   IF (P256 <= -1) THEN P256 = .;
   IF (P257 <= -1) THEN P257 = .;
   IF (P258 <= -1) THEN P258 = .;
   IF (P259 <= -1) THEN P259 = .;
   IF (P262A1 <= -1) THEN P262A1 = .;
   IF (P262A2 <= -1) THEN P262A2 = .;
   IF (P262A3 <= -1) THEN P262A3 = .;
   IF (P262A4 <= -1) THEN P262A4 = .;
   IF (P262A5 <= -1) THEN P262A5 = .;
   IF (P264A1 <= -1) THEN P264A1 = .;
   IF (P266A1 <= -1) THEN P266A1 = .;
   IF (P264A2 <= -1) THEN P264A2 = .;
   IF (P266A2 <= -1) THEN P266A2 = .;
   IF (P264A3 <= -1) THEN P264A3 = .;
   IF (P266A3 <= -1) THEN P266A3 = .;
   IF (P264A4 <= -1) THEN P264A4 = .;
   IF (P266A4 <= -1) THEN P266A4 = .;
   IF (P264A5 <= -1) THEN P264A5 = .;
   IF (P266A5 <= -1) THEN P266A5 = .;
   IF (P267 <= -1) THEN P267 = .;
   IF (P268M1 <= -1) THEN P268M1 = .;
   IF (P268M2 <= -1) THEN P268M2 = .;
   IF (P268M3 <= -1) THEN P268M3 = .;
   IF (P268M6 <= -1) THEN P268M6 = .;
   IF (P269 <= -1) THEN P269 = .;
   IF (P270M1 <= -1) THEN P270M1 = .;
   IF (P270M5 <= -1) THEN P270M5 = .;
   IF (P270M6 <= -1) THEN P270M6 = .;
   IF (P271 <= -1) THEN P271 = .;
   IF (P272M1 <= -1) THEN P272M1 = .;
   IF (P272M2 <= -1) THEN P272M2 = .;
   IF (P272M3 <= -1) THEN P272M3 = .;
   IF (P272M6 <= -1) THEN P272M6 = .;
   IF (P273 <= -1) THEN P273 = .;
   IF (P274 <= -1) THEN P274 = .;
   IF (P275 <= -1) THEN P275 = .;
   IF (P276 <= -1) THEN P276 = .;
   IF (P278 <= -1) THEN P278 = .;
   IF (P279 <= -1) THEN P279 = .;
   IF (P280 <= -1) THEN P280 = .;
   IF (P281 <= -1) THEN P281 = .;
   IF (P283 <= -1) THEN P283 = .;
   IF (P284 <= -1) THEN P284 = .;
   IF (P285 <= -1) THEN P285 = .;
   IF (P286 <= -1) THEN P286 = .;
   IF (P287 <= -1) THEN P287 = .;
   IF (P289 <= -1) THEN P289 = .;
   IF (P290 <= -1) THEN P290 = .;
   IF (P291 <= -1) THEN P291 = .;
   IF (P292 = 3) THEN P292 = .;
   IF (P292 <= -1) THEN P292 = .;
   IF (P294 = 3) THEN P294 = .;
   IF (P294 <= -1) THEN P294 = .;
   IF (P295 = 3) THEN P295 = .;
   IF (P295 <= -1) THEN P295 = .;
   IF (P296 <= -1) THEN P296 = .;
   IF (P297 <= -1) THEN P297 = .;
   IF (P298 <= -1) THEN P298 = .;
   IF (P299 <= -1) THEN P299 = .;
   IF (P301 <= -1) THEN P301 = .;
   IF (P302 <= -1) THEN P302 = .;
   IF (P303 <= -1) THEN P303 = .;
   IF (P304 <= -1) THEN P304 = .;
   IF (P305 <= -1) THEN P305 = .;
   IF (P306 <= -1) THEN P306 = .;
   IF (P307 <= -1) THEN P307 = .;
   IF (P308 <= -1) THEN P308 = .;
   IF (P309 <= -1) THEN P309 = .;
   IF (P310 <= -1) THEN P310 = .;
   IF (P311 <= -1) THEN P311 = .;
   IF (P312 = 3) THEN P312 = .;
   IF (P312 <= -1) THEN P312 = .;
   IF (P314 <= -1) THEN P314 = .;
   IF (P316 <= -1) THEN P316 = .;
   IF (P317 <= -1) THEN P317 = .;
   IF (P319 <= -1) THEN P319 = .;
   IF (P321 <= -1) THEN P321 = .;
   IF (P323 <= -1) THEN P323 = .;
   IF (P324 <= -1) THEN P324 = .;
   IF (P326 <= -1) THEN P326 = .;
   IF (P332M1 <= -1) THEN P332M1 = .;
   IF (P333A1 <= -1) THEN P333A1 = .;
   IF (P332M2 <= -1) THEN P332M2 = .;
   IF (P333A2 <= -1) THEN P333A2 = .;
   IF (P332M3 <= -1) THEN P332M3 = .;
   IF (P333A3 <= -1) THEN P333A3 = .;
   IF (P332M4 <= -1) THEN P332M4 = .;
   IF (P333A4 <= -1) THEN P333A4 = .;
   IF (P334 <= -1) THEN P334 = .;
   IF (P335M1 <= -1) THEN P335M1 = .;
   IF (P335M2 <= -1) THEN P335M2 = .;
   IF (P335M3 <= -1) THEN P335M3 = .;
   IF (P336 <= -1) THEN P336 = .;
   IF (P337 <= -1) THEN P337 = .;
   IF (P338 <= -1) THEN P338 = .;
   IF (P342 <= -1) THEN P342 = .;
   IF (P344 <= -1) THEN P344 = .;
   IF (P345 <= -1) THEN P345 = .;
   IF (P346 <= -1) THEN P346 = .;
   IF (P347 <= -1) THEN P347 = .;
   IF (P348 <= -1) THEN P348 = .;
   IF (P350 <= -1) THEN P350 = .;
   IF (P351 <= -1) THEN P351 = .;
   IF (P352 <= -1) THEN P352 = .;
   IF (P353 <= -1) THEN P353 = .;
   IF (P354 <= -1) THEN P354 = .;
   IF (P355 <= -1) THEN P355 = .;
   IF (P356 <= -1) THEN P356 = .;
   IF (P357 <= -1) THEN P357 = .;
   IF (P358 <= -1) THEN P358 = .;
   IF (P359 <= -1) THEN P359 = .;
   IF (P360 <= -1) THEN P360 = .;
   IF (P361 <= -1) THEN P361 = .;
   IF (P362 <= -1) THEN P362 = .;
   IF (P363 <= -1) THEN P363 = .;
   IF (P364 <= -1) THEN P364 = .;
   IF (P365 <= -1) THEN P365 = .;
   IF (P367 <= -1) THEN P367 = .;
   IF (P368 <= -1) THEN P368 = .;
   IF (P369 <= -1) THEN P369 = .;
   IF (P370 <= -1) THEN P370 = .;
   IF (P378 <= -1) THEN P378 = .;
   IF (P379 <= -1) THEN P379 = .;
   IF (P380 <= -1) THEN P380 = .;
   IF (P381 <= -1) THEN P381 = .;
   IF (P382 <= -1) THEN P382 = .;
   IF (P383 <= -1) THEN P383 = .;
   IF (P384 <= -1) THEN P384 = .;
   IF (P385 <= -1) THEN P385 = .;
   IF (P386 <= -1) THEN P386 = .;
   IF (P387 <= -1) THEN P387 = .;
   IF (P388 <= -1) THEN P388 = .;
   IF (P389 <= -1) THEN P389 = .;
   IF (P390 <= -1) THEN P390 = .;
   IF (P391 <= -1) THEN P391 = .;
   IF (P392 <= -1) THEN P392 = .;
   IF (P393 <= -1) THEN P393 = .;
   IF (P394 <= -1) THEN P394 = .;
   IF (P395 <= -1) THEN P395 = .;
   IF (P397 <= -1) THEN P397 = .;
   IF (P400A2 <= -1) THEN P400A2 = .;
   IF (P400A3 <= -1) THEN P400A3 = .;
   IF (P400A5 <= -1) THEN P400A5 = .;
   IF (P400A10 <= -1) THEN P400A10 = .;
   IF (P400A11 <= -1) THEN P400A11 = .;
   IF (P400A12 <= -1) THEN P400A12 = .;
   IF (P400A15 <= -1) THEN P400A15 = .;
   IF (P400A16 <= -1) THEN P400A16 = .;
   IF (P400A17 <= -1) THEN P400A17 = .;
   IF (P402 <= -1) THEN P402 = .;
   IF (P404A21 <= -1) THEN P404A21 = .;
   IF (P408 <= -1) THEN P408 = .;
   IF (P409 <= -1) THEN P409 = .;
   IF (P410 <= -1) THEN P410 = .;
   IF (P411 = 3) THEN P411 = .;
   IF (P411 <= -1) THEN P411 = .;
   IF (P412 <= -1) THEN P412 = .;
   IF (P413 <= -1) THEN P413 = .;
   IF (P415 = 3) THEN P415 = .;
   IF (P415 <= -1) THEN P415 = .;
   IF (P416 = 3) THEN P416 = .;
   IF (P416 <= -1) THEN P416 = .;
   IF (P417 <= -1) THEN P417 = .;
   IF (P418 <= -1) THEN P418 = .;
   IF (P419 <= -1) THEN P419 = .;
   IF (P420 <= -1) THEN P420 = .;
   IF (P423 = 6) THEN P423 = .;
   IF (P423 <= -1) THEN P423 = .;
   IF (P425 <= -1) THEN P425 = .;
   IF (P426 <= -1) THEN P426 = .;
   IF (P428 <= -1) THEN P428 = .;
   IF (P430 <= -1) THEN P430 = .;
   IF (P431M1 <= -1) THEN P431M1 = .;
   IF (P431M2 <= -1) THEN P431M2 = .;
   IF (P431M3 <= -1) THEN P431M3 = .;
   IF (P431M4 <= -1) THEN P431M4 = .;
   IF (P431M5 <= -1) THEN P431M5 = .;
   IF (P431M6 <= -1) THEN P431M6 = .;
   IF (P431M7 <= -1) THEN P431M7 = .;
   IF (P431M8 <= -1) THEN P431M8 = .;
   IF (P431M9 <= -1) THEN P431M9 = .;
   IF (P431M10 <= -1) THEN P431M10 = .;
   IF (P431M11 <= -1) THEN P431M11 = .;
   IF (P431M12 <= -1) THEN P431M12 = .;
   IF (P431M15 <= -1) THEN P431M15 = .;
   IF (P431M16 <= -1) THEN P431M16 = .;
   IF (P434 <= -1) THEN P434 = .;
   IF (P437A1 <= -1) THEN P437A1 = .;
   IF (P438A1 <= -1) THEN P438A1 = .;
   IF (P441A1 <= -1) THEN P441A1 = .;
   IF (P442A1 <= -1) THEN P442A1 = .;
   IF (P441A2 <= -1) THEN P441A2 = .;
   IF (P442A2 <= -1) THEN P442A2 = .;
   IF (P445 <= -1) THEN P445 = .;
   IF (P446 <= -1) THEN P446 = .;
   IF (P449A1 <= -1) THEN P449A1 = .;
   IF (P450M1 <= -1) THEN P450M1 = .;
   IF (P450M2 <= -1) THEN P450M2 = .;
   IF (P450M3 <= -1) THEN P450M3 = .;
   IF (P450M4 <= -1) THEN P450M4 = .;
   IF (P450M5 <= -1) THEN P450M5 = .;
   IF (P450M6 <= -1) THEN P450M6 = .;
   IF (P450M7 <= -1) THEN P450M7 = .;
   IF (P450M8 <= -1) THEN P450M8 = .;
   IF (P450M9 <= -1) THEN P450M9 = .;
   IF (P450M10 <= -1) THEN P450M10 = .;
   IF (P450M11 <= -1) THEN P450M11 = .;
   IF (P451 <= -1) THEN P451 = .;
   IF (P452 <= -1) THEN P452 = .;
   IF (P453 <= -1) THEN P453 = .;
   IF (P454 <= -1) THEN P454 = .;
   IF (P456 <= -1) THEN P456 = .;
   IF (P460M2 <= -1) THEN P460M2 = .;
   IF (P460 <= -1) THEN P460 = .;
   IF (P462 <= -1) THEN P462 = .;
   IF (P464 <= -1) THEN P464 = .;
   IF (P465 <= -1) THEN P465 = .;
   IF (P466 = 3) THEN P466 = .;
   IF (P466 <= -1) THEN P466 = .;
   IF (P467 = 3) THEN P467 = .;
   IF (P467 <= -1) THEN P467 = .;
   IF (P468 <= -1) THEN P468 = .;
   IF (P469 <= -1) THEN P469 = .;
   IF (P470 <= -1) THEN P470 = .;
   IF (P471 <= -1) THEN P471 = .;
   IF (P474A1 <= -1) THEN P474A1 = .;
   IF (P474A2 <= -1) THEN P474A2 = .;
   IF (P474A3 <= -1) THEN P474A3 = .;
   IF (P474A4 <= -1) THEN P474A4 = .;
   IF (P474A5 <= -1) THEN P474A5 = .;
   IF (P474A6 <= -1) THEN P474A6 = .;
   IF (P474A7 <= -1) THEN P474A7 = .;
   IF (P477M1 <= -1) THEN P477M1 = .;
   IF (P477M2 <= -1) THEN P477M2 = .;
   IF (P479 <= -1) THEN P479 = .;
   IF (P481 <= -1) THEN P481 = .;
   IF (P485A1 <= -1) THEN P485A1 = .;
   IF (P485A2 <= -1) THEN P485A2 = .;
   IF (P485A3 <= -1) THEN P485A3 = .;
   IF (P485A4 <= -1) THEN P485A4 = .;
   IF (P485A5 <= -1) THEN P485A5 = .;
   IF (P485A6 <= -1) THEN P485A6 = .;
   IF (P485A7 <= -1) THEN P485A7 = .;
   IF (P485A8 <= -1) THEN P485A8 = .;
   IF (P485A9 <= -1) THEN P485A9 = .;
   IF (P485A10 <= -1) THEN P485A10 = .;
   IF (P486 <= -1) THEN P486 = .;
   IF (P487 <= -1) THEN P487 = .;
   IF (P489 <= -1) THEN P489 = .;
   IF (P494A1 <= -1) THEN P494A1 = .;
   IF (P495A1 = 6) THEN P495A1 = .;
   IF (P495A1 <= -1) THEN P495A1 = .;
   IF (P494A2 <= -1) THEN P494A2 = .;
   IF (P495A2 = 6) THEN P495A2 = .;
   IF (P495A2 <= -1) THEN P495A2 = .;
   IF (P494A3 <= -1) THEN P494A3 = .;
   IF (P495A3 = 6) THEN P495A3 = .;
   IF (P495A3 <= -1) THEN P495A3 = .;
   IF (P494A4 <= -1) THEN P494A4 = .;
   IF (P495A4 = 6) THEN P495A4 = .;
   IF (P495A4 <= -1) THEN P495A4 = .;
   IF (P494A5 <= -1) THEN P494A5 = .;
   IF (P495A5 = 6) THEN P495A5 = .;
   IF (P495A5 <= -1) THEN P495A5 = .;
   IF (P497 <= -1) THEN P497 = .;
   IF (P498 <= -1) THEN P498 = .;
   IF (P499 <= -1) THEN P499 = .;
   IF (P500 <= -1) THEN P500 = .;
   IF (P501 <= -1) THEN P501 = .;
   IF (P502 <= -1) THEN P502 = .;
   IF (P503 <= -1) THEN P503 = .;
   IF (P508 <= -1) THEN P508 = .;
   IF (P509 <= -1) THEN P509 = .;
   IF (P510 <= -1) THEN P510 = .;
   IF (P512A1 <= -1) THEN P512A1 = .;
   IF (P514A1 <= -1) THEN P514A1 = .;
   IF (P513A2 <= -1) THEN P513A2 = .;
   IF (P514A2 <= -1) THEN P514A2 = .;
   IF (P513A3 <= -1) THEN P513A3 = .;
   IF (P514A3 <= -1) THEN P514A3 = .;
   IF (P521 <= -1) THEN P521 = .;
   IF (P522 <= -1) THEN P522 = .;
   IF (P523 <= -1) THEN P523 = .;
   IF (P524 <= -1) THEN P524 = .;
   IF (P525 <= -1) THEN P525 = .;
   IF (P526 <= -1) THEN P526 = .;
   IF (P528 <= -1) THEN P528 = .;
   IF (P529 <= -1) THEN P529 = .;
   IF (P530 <= -1) THEN P530 = .;
   IF (P532 <= -1) THEN P532 = .;
   IF (P554 <= -1) THEN P554 = .;
   IF (PBEERVOL <= -1) THEN PBEERVOL = .;
   IF (PWINEVOL <= -1) THEN PWINEVOL = .;
   IF (PLIQUVOL <= -1) THEN PLIQUVOL = .;
   IF (IN_4411 <= -1) THEN IN_4411 = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT P4 p4ffffff. P5 p5ffffff. P7 p7ffffff.
         P11 p11fffff. P13 p13fffff. P26 p26fffff.
         P87 p87fffff. P88 p88fffff. P92 p92fffff.
         P96 p96fffff. P102M1 p102m1ff. P102M2 p102m2ff.
         P102M3 p102m3ff. P102M4 p102m4ff. P114 p114ffff.
         P121 p121ffff. P130 p130ffff. PRGMTYPE prgmtype.
         TRT2 trt2ffff. PRG2 prg2ffff. CELL cell.
         CELL2 cell2fff. P137 p137ffff. P138 p138ffff.
         P139M1 p139m1ff. P139M2 p139m2ff. P139M3 p139m3ff.
         P139M4 p139m4ff. P139M5 p139m5ff. P139M6 p139m6ff.
         P139M7 p139m7ff. P145 p145ffff. P146 p146ffff.
         P150 p150ffff. P155 p155ffff. P159 p159ffff.
         P160 p160ffff. P161 p161ffff. P162 p162ffff.
         P164 p164ffff. P165 p165ffff. P172A1 p172a1ff.
         P172A2 p172a2ff. P172A3 p172a3ff. P172A4 p172a4ff.
         P172A5 p172a5ff. P172A6 p172a6ff. P172A7 p172a7ff.
         P172A8 p172a8ff. P172A9 p172a9ff. P172A10 p172a10f.
         P172A11 p172a11f. P172A12 p172a12f. P181A1 p181a1ff.
         P186A1 p186a1ff. P187A1 p187a1ff. P188A1 p188a1ff.
         P181A2 p181a2ff. P186A2 p186a2ff. P187A2 p187a2ff.
         P188A2 p188a2ff. P181A3 p181a3ff. P182A3 p182a3ff.
         P183A3 p183a3ff. P186A3 p186a3ff. P187A3 p187a3ff.
         P188A3 p188a3ff. P181A4 p181a4ff. P182A4 p182a4ff.
         P183A4 p183a4ff. P186A4 p186a4ff. P187A4 p187a4ff.
         P188A4 p188a4ff. P181A5 p181a5ff. P186A5 p186a5ff.
         P187A5 p187a5ff. P188A5 p188a5ff. P181A6 p181a6ff.
         P186A6 p186a6ff. P187A6 p187a6ff. P188A6 p188a6ff.
         P181A7 p181a7ff. P186A7 p186a7ff. P187A7 p187a7ff.
         P188A7 p188a7ff. P181A8 p181a8ff. P186A8 p186a8ff.
         P187A8 p187a8ff. P188A8 p188a8ff. P181A9 p181a9ff.
         P186A9 p186a9ff. P187A9 p187a9ff. P188A9 p188a9ff.
         P181A10 p181a10f. P186A10 p186a10f. P187A10 p187a10f.
         P188A10 p188a10f. P181A11 p181a11f. P186A11 p186a11f.
         P187A11 p187a11f. P188A11 p188a11f. P181A12 p181a12f.
         P186A12 p186a12f. P187A12 p187a12f. P188A12 p188a12f.
         P189 p189ffff. P190 p190ffff. P191 p191ffff.
         P192 p192ffff. P193 p193ffff. P194 p194ffff.
         P195 p195ffff. P196 p196ffff. P197 p197ffff.
         P198 p198ffff. P199 p199ffff. P201 p201ffff.
         P202 p202ffff. P203 p203ffff. P204 p204ffff.
         P205 p205ffff. P206 p206ffff. P208A1 p208a1ff.
         P209A1 p209a1ff. P210A1 p210a1ff. P213A1 p213a1ff.
         P208A2 p208a2ff. P209A2 p209a2ff. P210A2 p210a2ff.
         P213A2 p213a2ff. P208A3 p208a3ff. P209A3 p209a3ff.
         P210A3 p210a3ff. P221 p221ffff. P223 p223ffff.
         P225 p225ffff. P227 p227ffff. P229 p229ffff.
         P237 p237ffff. P238 p238ffff. P239 p239ffff.
         P240 p240ffff. P241 p241ffff. P242 p242ffff.
         P243 p243ffff. P244 p244ffff. P245 p245ffff.
         P249A1 p249a1ff. P250A1 p250a1ff. P249A2 p249a2ff.
         P250A2 p250a2ff. P249A3 p249a3ff. P250A3 p250a3ff.
         P249A4 p249a4ff. P250A4 p250a4ff. P249A5 p249a5ff.
         P250A5 p250a5ff. P249A6 p249a6ff. P250A6 p250a6ff.
         P249A7 p249a7ff. P250A7 p250a7ff. P249A8 p249a8ff.
         P250A8 p250a8ff. P249A9 p249a9ff. P250A9 p250a9ff.
         P252 p252ffff. P254 p254ffff. P255 p255ffff.
         P256 p256ffff. P257 p257ffff. P258 p258ffff.
         P259 p259ffff. P262A1 p262a1ff. P262A2 p262a2ff.
         P262A3 p262a3ff. P262A4 p262a4ff. P262A5 p262a5ff.
         P264A1 p264a1ff. P266A1 p266a1ff. P264A2 p264a2ff.
         P266A2 p266a2ff. P264A3 p264a3ff. P266A3 p266a3ff.
         P264A4 p264a4ff. P266A4 p266a4ff. P264A5 p264a5ff.
         P266A5 p266a5ff. P267 p267ffff. P268M1 p268m1ff.
         P268M2 p268m2ff. P268M3 p268m3ff. P268M6 p268m6ff.
         P269 p269ffff. P270M1 p270m1ff. P270M5 p270m5ff.
         P270M6 p270m6ff. P271 p271ffff. P272M1 p272m1ff.
         P272M2 p272m2ff. P272M3 p272m3ff. P272M6 p272m6ff.
         P273 p273ffff. P274 p274ffff. P275 p275ffff.
         P276 p276ffff. P278 p278ffff. P279 p279ffff.
         P280 p280ffff. P281 p281ffff. P283 p283ffff.
         P284 p284ffff. P285 p285ffff. P286 p286ffff.
         P287 p287ffff. P289 p289ffff. P290 p290ffff.
         P291 p291ffff. P292 p292ffff. P294 p294ffff.
         P295 p295ffff. P296 p296ffff. P297 p297ffff.
         P298 p298ffff. P299 p299ffff. P301 p301ffff.
         P302 p302ffff. P303 p303ffff. P304 p304ffff.
         P305 p305ffff. P306 p306ffff. P307 p307ffff.
         P308 p308ffff. P309 p309ffff. P310 p310ffff.
         P311 p311ffff. P312 p312ffff. P316 p316ffff.
         P317 p317ffff. P319 p319ffff. P321 p321ffff.
         P323 p323ffff. P324 p324ffff. P326 p326ffff.
         P332M1 p332m1ff. P333A1 p333a1ff. P332M2 p332m2ff.
         P333A2 p333a2ff. P332M3 p332m3ff. P333A3 p333a3ff.
         P332M4 p332m4ff. P333A4 p333a4ff. P334 p334ffff.
         P335M1 p335m1ff. P335M2 p335m2ff. P335M3 p335m3ff.
         P336 p336ffff. P337 p337ffff. P338 p338ffff.
         P342 p342ffff. P344 p344ffff. P345 p345ffff.
         P346 p346ffff. P347 p347ffff. P348 p348ffff.
         P350 p350ffff. P351 p351ffff. P352 p352ffff.
         P353 p353ffff. P354 p354ffff. P355 p355ffff.
         P356 p356ffff. P357 p357ffff. P358 p358ffff.
         P359 p359ffff. P360 p360ffff. P361 p361ffff.
         P362 p362ffff. P363 p363ffff. P364 p364ffff.
         P365 p365ffff. P367 p367ffff. P368 p368ffff.
         P369 p369ffff. P378 p378ffff. P379 p379ffff.
         P380 p380ffff. P381 p381ffff. P382 p382ffff.
         P383 p383ffff. P384 p384ffff. P385 p385ffff.
         P386 p386ffff. P387 p387ffff. P388 p388ffff.
         P389 p389ffff. P390 p390ffff. P391 p391ffff.
         P392 p392ffff. P393 p393ffff. P394 p394ffff.
         P395 p395ffff. P397 p397ffff. P400A2 p400a2ff.
         P400A3 p400a3ff. P400A5 p400a5ff. P400A10 p400a10f.
         P400A11 p400a11f. P400A12 p400a12f. P400A15 p400a15f.
         P400A16 p400a16f. P400A17 p400a17f. P402 p402ffff.
         P404A21 p404a21f. P408 p408ffff. P409 p409ffff.
         P410 p410ffff. P411 p411ffff. P412 p412ffff.
         P413 p413ffff. P415 p415ffff. P416 p416ffff.
         P417 p417ffff. P418 p418ffff. P419 p419ffff.
         P420 p420ffff. P423 p423ffff. P425 p425ffff.
         P426 p426ffff. P428 p428ffff. P430 p430ffff.
         P431M1 p431m1ff. P431M2 p431m2ff. P431M3 p431m3ff.
         P431M4 p431m4ff. P431M5 p431m5ff. P431M6 p431m6ff.
         P431M7 p431m7ff. P431M8 p431m8ff. P431M9 p431m9ff.
         P431M10 p431m10f. P431M11 p431m11f. P431M12 p431m12f.
         P431M15 p431m15f. P431M16 p431m16f. P434 p434ffff.
         P437A1 p437a1ff. P438A1 p438a1ff. P441A1 p441a1ff.
         P442A1 p442a1ff. P441A2 p441a2ff. P442A2 p442a2ff.
         P445 p445ffff. P446 p446ffff. P449A1 p449a1ff.
         P450M1 p450m1ff. P450M2 p450m2ff. P450M3 p450m3ff.
         P450M4 p450m4ff. P450M5 p450m5ff. P450M6 p450m6ff.
         P450M7 p450m7ff. P450M8 p450m8ff. P450M9 p450m9ff.
         P450M10 p450m10f. P450M11 p450m11f. P451 p451ffff.
         P452 p452ffff. P453 p453ffff. P454 p454ffff.
         P456 p456ffff. P460M2 p460m2ff. P460 p460ffff.
         P462 p462ffff. P464 p464ffff. P465 p465ffff.
         P466 p466ffff. P467 p467ffff. P468 p468ffff.
         P469 p469ffff. P470 p470ffff. P471 p471ffff.
         P474A1 p474a1ff. P474A2 p474a2ff. P474A3 p474a3ff.
         P474A4 p474a4ff. P474A5 p474a5ff. P474A6 p474a6ff.
         P474A7 p474a7ff. P477M1 p477m1ff. P477M2 p477m2ff.
         P479 p479ffff. P481 p481ffff. P485A1 p485a1ff.
         P485A2 p485a2ff. P485A3 p485a3ff. P485A4 p485a4ff.
         P485A5 p485a5ff. P485A6 p485a6ff. P485A7 p485a7ff.
         P485A8 p485a8ff. P485A9 p485a9ff. P485A10 p485a10f.
         P486 p486ffff. P487 p487ffff. P489 p489ffff.
         P494A1 p494a1ff. P495A1 p495a1ff. P494A2 p494a2ff.
         P495A2 p495a2ff. P494A3 p494a3ff. P495A3 p495a3ff.
         P494A4 p494a4ff. P495A4 p495a4ff. P494A5 p494a5ff.
         P495A5 p495a5ff. P497 p497ffff. P498 p498ffff.
         P499 p499ffff. P500 p500ffff. P501 p501ffff.
         P502 p502ffff. P503 p503ffff. P508 p508ffff.
         P509 p509ffff. P510 p510ffff. P512A1 p512a1ff.
         P514A1 p514a1ff. P513A2 p513a2ff. P514A2 p514a2ff.
         P513A3 p513a3ff. P514A3 p514a3ff. P521 p521ffff.
         P522 p522ffff. P524 p524ffff. P525 p525ffff.
         P526 p526ffff. P528 p528ffff. P529 p529ffff.
         P530 p530ffff. PBEERVOL pbeervol. PWINEVOL pwinevol.
         PLIQUVOL pliquvol. IN_4411 in_4411f.  ;
*/

RUN ;
